import sys
from PySide.QtGui import *
import unittest

class Bug640(unittest.TestCase):
    def testIt(self):
        option = QStyleOptionGraphicsItem()
        a = option.state # crash!?

if __name__ == "__main__":
   unittest.main()



#!/usr/bin/python
import unittest
from PySide.QtCore import *


class SetPropOnCtorTest(unittest.TestCase):
    def testIt(self):
        obj = QEventTransition(targetStates = [QState()])
        self.assertEqual(len(obj.targetStates()), 1);

if __name__ == '__main__':
    unittest.main()



import unittest
import os
from helper import UsesQApplication

from PySide import QtCore, QtGui
from PySide.QtUiTools import QUiLoader

class BugTest(UsesQApplication):
    def testCase(self):
        w = QtGui.QWidget()
        loader = QUiLoader()

        filePath = os.path.join(os.path.dirname(__file__), 'test.ui')
        result = loader.load(filePath, w)
        self.assert_(isinstance(result.child_object, QtGui.QFrame))

if __name__ == '__main__':
    unittest.main()





import unittest

from PySide.QtGui import QTextDocument, QTextCursor

class QTextDocumentTest(unittest.TestCase):

    def testUndoRedo(self):
        text = 'foobar'
        doc = QTextDocument(text)

        self.assertFalse(doc.isRedoAvailable())
        self.assertTrue(doc.isUndoAvailable())
        self.assertEqual(doc.toPlainText(), text)

        cursor = QTextCursor(doc)
        doc.undo(cursor)

        self.assertTrue(doc.isRedoAvailable())
        self.assertFalse(doc.isUndoAvailable())
        self.assertEqual(doc.toPlainText(), '')

        doc.redo(cursor)

        self.assertFalse(doc.isRedoAvailable())
        self.assertTrue(doc.isUndoAvailable())
        self.assertEqual(doc.toPlainText(), text)

if __name__ == '__main__':
    unittest.main()




import unittest
import sys
from PySide.QtGui import QLabel, QApplication, QPixmap

class TestLabelPixmap(unittest.TestCase):
    def testReference(self):
        l = QLabel()
        p = QPixmap()
        l.setPixmap(p) # doesn't increment pixmap ref because this makes a copy
        self.assertEqual(sys.getrefcount(p), 2)

        p = l.pixmap() # this increment the reference because this is an internal pointer
        self.assertEqual(sys.getrefcount(p), 3)

        p2 = l.pixmap()
        self.assertEqual(p, p2)

if __name__ == '__main__':
    app = QApplication([])
    unittest.main()




#!/usr/bin/python

import unittest
from testbinding import TestObject
from PySide.QtCore import QObject, SIGNAL

'''Tests the behaviour of signals with default values when emitted from Python.'''

class SignalEmissionFromPython(unittest.TestCase):

    def setUp(self):
        self.obj1 = TestObject(0)
        self.obj2 = TestObject(0)
        self.one_called = 0
        self.two_called = 0

    def tearDown(self):
        del self.obj1
        del self.obj2
        del self.one_called
        del self.two_called

    def testConnectNewStyleEmitVoidSignal(self):
        def callbackOne():
            self.one_called += 1
            self.obj2.signalWithDefaultValue.emit()
        def callbackTwo():
            self.two_called += 1
        self.obj1.signalWithDefaultValue.connect(callbackOne)
        self.obj2.signalWithDefaultValue.connect(callbackTwo)
        self.obj1.emitSignalWithDefaultValue_void()
        self.obj2.emitSignalWithDefaultValue_void()
        self.assertEqual(self.one_called, 1)
        self.assertEqual(self.two_called, 2)

    def testConnectOldStyleEmitVoidSignal(self):
        def callbackOne():
            self.one_called += 1
            self.obj2.signalWithDefaultValue.emit()
        def callbackTwo():
            self.two_called += 1
        QObject.connect(self.obj1, SIGNAL('signalWithDefaultValue()'), callbackOne)
        QObject.connect(self.obj2, SIGNAL('signalWithDefaultValue()'), callbackTwo)
        self.obj1.emitSignalWithDefaultValue_void()
        self.obj2.emitSignalWithDefaultValue_void()
        self.assertEqual(self.one_called, 1)
        self.assertEqual(self.two_called, 2)

    def testConnectNewStyleEmitBoolSignal(self):
        def callbackOne():
            self.one_called += 1
            self.obj2.signalWithDefaultValue[bool].emit(True)
        def callbackTwo():
            self.two_called += 1
        self.obj1.signalWithDefaultValue.connect(callbackOne)
        self.obj2.signalWithDefaultValue.connect(callbackTwo)
        self.obj1.emitSignalWithDefaultValue_void()
        self.obj2.emitSignalWithDefaultValue_void()
        self.assertEqual(self.one_called, 1)
        self.assertEqual(self.two_called, 2)

    def testConnectOldStyleEmitBoolSignal(self):
        def callbackOne():
            self.one_called += 1
            self.obj2.signalWithDefaultValue[bool].emit(True)
        def callbackTwo():
            self.two_called += 1
        QObject.connect(self.obj1, SIGNAL('signalWithDefaultValue()'), callbackOne)
        QObject.connect(self.obj2, SIGNAL('signalWithDefaultValue()'), callbackTwo)
        self.obj1.emitSignalWithDefaultValue_void()
        self.obj2.emitSignalWithDefaultValue_void()
        self.assertEqual(self.one_called, 1)
        self.assertEqual(self.two_called, 2)



if __name__ == '__main__':
    unittest.main()




''' unit test for BUG #1084 '''

import unittest
from PySide import QtNetwork
import py3kcompat as py3k

class QTcpSocketTestCase(unittest.TestCase):
    def setUp(self):
        self.sock = QtNetwork.QTcpSocket()
        self.sock.connectToHost('127.0.0.1', 25)

    def testIt(self):
        self.sock.write(py3k.unicode_('quit'))

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python

import unittest
from testbinding import TestObject

'''Tests the behaviour of homonymous signals and slots.'''

class HomonymousSignalAndMethodTest(unittest.TestCase):

    def setUp(self):
        self.value = 123
        self.called = False
        self.obj = TestObject(self.value)

    def tearDown(self):
        del self.value
        del self.called
        del self.obj

    def testIdValueSignalEmission(self):
        def callback(idValue):
            self.assertEqual(idValue, self.value)
        self.obj.idValue.connect(callback)
        self.obj.emitIdValueSignal()

    def testStaticMethodDoubleSignalEmission(self):
        def callback():
            self.called = True
        self.obj.staticMethodDouble.connect(callback)
        self.obj.emitStaticMethodDoubleSignal()
        self.assert_(self.called)

    def testSignalNotCallable(self):
        self.assertRaises(TypeError, self.obj.justASignal)

    def testCallingInstanceMethodWithArguments(self):
        self.assertRaises(TypeError, TestObject.idValue, 1)

    def testCallingInstanceMethodWithoutArguments(self):
        self.assertRaises(TypeError, TestObject.idValue)

    def testHomonymousSignalAndMethod(self):
        self.assertEqual(self.obj.idValue(), self.value)

    def testHomonymousSignalAndStaticMethod(self):
        self.assertEqual(TestObject.staticMethodDouble(3), 6)

    def testHomonymousSignalAndStaticMethodFromInstance(self):
        self.assertEqual(self.obj.staticMethodDouble(4), 8)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python

import sys
from optparse import OptionParser

import PyQt4
from PyQt4 import QtCore, QtGui, QtNetwork

modules = [QtCore, QtGui, QtNetwork]

def search(klass, method=None):
    for module in modules:
        try:
            klass_obj = getattr(module, klass)
            print "%s *found* on module %s" % (klass, module.__name__)
        except AttributeError:
            print "%s not found on module %s" % (klass, module.__name__)
            continue

        if method is None:
            continue

        try:
            meth_obj = getattr(klass_obj, method)

            meth_name = ".".join([klass, method])
            klass_name = ".".join([module.__name__, klass])
            print "\"%s\" *found* on class %s" % (meth_name, klass_name)
        except AttributeError:
            print "\"%s\" not found on class %s" % (method, klass)


def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]

    try:
        klass, method = argv[0].split(".")
    except:
        klass = argv[0]
        method = None

    search(klass, method)

if __name__ == '__main__':
    main()



#!/usr/bin/python
'''Test cases for QLineF'''

import unittest
import os

from PySide.QtCore import *

class TestQLineF (unittest.TestCase):
    def testIntersect(self):
        l1 = QLineF(0, 0, 1, 0)
        l2 = QLineF(1, -1, 1, 1)
        tuple_ = l1.intersect(l2)
        self.assertEquals(tuple, tuple_.__class__)
        (value, p) = tuple_
        self.assertEquals(QLineF.BoundedIntersection, value)
        self.assertEqual(QPointF(1, 0), p)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from PySide import QtCore

global qApp

class objTest(QtCore.QObject):

    def __init__(self, parent=None):
        QtCore.QObject.__init__(self, parent)

        self.ok = False

    def slot(self):
        global qApp
 
        self.ok = True
        qApp.quit()



class slotTest(unittest.TestCase):
    def quit_app(self):
        global qApp
       
        qApp.quit() 

    def testBasic(self):
        global qApp
        timer = QtCore.QTimer()
        timer.setInterval(100)

        my_obj = objTest()
        my_slot = QtCore.SLOT("slot()")
        QtCore.QObject.connect(timer, QtCore.SIGNAL("timeout()"), my_obj, my_slot)
        timer.start(100)

        QtCore.QTimer.singleShot(1000, self.quit_app)
        qApp.exec_()

        self.assert_(my_obj.ok)   


if __name__ == '__main__':
    global qApp
    qApp = QtCore.QCoreApplication([])
    unittest.main()



#!/usr/bin/python

import unittest
from testbinding import PySideCPP, TestObjectWithoutNamespace

class ModelViewTest(unittest.TestCase):

    def callback(self, o):
        self._called = o

    def testWithoutNamespace(self):
        self._called = None
        o = PySideCPP.TestObjectWithNamespace(None)
        o.emitSignal.connect(self.callback)
        o.emitSignal.emit(o)
        self.assert_(o == self._called)

        self._called = None
        o = PySideCPP.TestObjectWithNamespace(None)
        o.emitSignal.connect(self.callback)
        o.callSignal(o)
        self.assert_(o == self._called)

    def testWithNamespace(self):
        self._called = None
        o = PySideCPP.TestObjectWithNamespace(None)
        o.emitSignalWithNamespace.connect(self.callback)
        o.emitSignalWithNamespace.emit(o)
        self.assert_(o == self._called)

        self._called = None
        o = PySideCPP.TestObjectWithNamespace(None)
        o.emitSignalWithNamespace.connect(self.callback)
        o.callSignalWithNamespace(o)
        self.assert_(o == self._called)


    def testWithoutNamespace1(self):
        self._called = None
        o = TestObjectWithoutNamespace(None)
        o.emitSignal.connect(self.callback)
        o.emitSignal.emit(o)
        self.assert_(o == self._called)

        self._called = None
        o = TestObjectWithoutNamespace(None)
        o.emitSignal.connect(self.callback)
        o.callSignal(o)
        self.assert_(o == self._called)

    def testWithNamespace1(self):
        self._called = None
        o = TestObjectWithoutNamespace(None)
        o.emitSignalWithNamespace.connect(self.callback)
        o.emitSignalWithNamespace.emit(o)
        self.assert_(o == self._called)

        self._called = None
        o = TestObjectWithoutNamespace(None)
        o.emitSignalWithNamespace.connect(self.callback)
        o.callSignalWithNamespace(o)
        self.assert_(o == self._called)

    def testTypedfWithouNamespace(self):
        self._called = None
        o = PySideCPP.TestObjectWithNamespace(None)
        o.emitSignalWithTypedef.connect(self.callback)
        o.emitSignalWithTypedef.emit(10)
        self.assertEqual(10, self._called)

        self._called = None
        o = PySideCPP.TestObjectWithNamespace(None)
        o.emitSignalWithTypedef.connect(self.callback)
        o.callSignalWithTypedef(10)
        self.assertEqual(10, self._called)

    def testTypedefWithNamespace(self):
        self._called = None
        o = TestObjectWithoutNamespace(None)
        o.emitSignalWithTypedef.connect(self.callback)
        o.emitSignalWithTypedef.emit(10)
        self.assertEqual(10, self._called)

        self._called = None
        o = TestObjectWithoutNamespace(None)
        o.emitSignalWithTypedef.connect(self.callback)
        o.callSignalWithTypedef(10)
        self.assertEqual(10, self._called)

if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-

''' Test case for QObject::connectNotify()'''

import unittest
from PySide.QtCore import *
from helper import UsesQCoreApplication

def cute_slot():
    pass

class Obj(QObject):
    def __init__(self):
        QObject.__init__(self)
        self.con_notified = False
        self.dis_notified = False
        self.signal = ""

    def connectNotify(self, signal):
        self.con_notified = True
        self.signal = signal

    def disconnectNotify(self, signal):
        self.dis_notified = True

    def reset(self):
        self.con_notified = False
        self.dis_notified = False

class TestQObjectConnectNotify(UsesQCoreApplication):
    '''Test case for QObject::connectNotify'''
    def setUp(self):
        UsesQCoreApplication.setUp(self)
        self.called = False             

    def tearDown(self):
        UsesQCoreApplication.tearDown(self)

    def testBasic(self):
        sender = Obj()
        receiver = QObject()
        sender.connect(SIGNAL("destroyed()"), receiver, SLOT("deleteLater()"))
        self.assert_(sender.con_notified)
        self.assertEqual(sender.signal, SIGNAL("destroyed()"))
        sender.disconnect(SIGNAL("destroyed()"), receiver, SLOT("deleteLater()"))
        self.assert_(sender.dis_notified)

    def testPySignal(self):
        sender = Obj()
        receiver = QObject()
        sender.connect(SIGNAL("foo()"), receiver, SLOT("deleteLater()"))
        self.assert_(sender.con_notified)
        sender.disconnect(SIGNAL("foo()"), receiver, SLOT("deleteLater()"))
        self.assert_(sender.dis_notified)

    def testPySlots(self):
        sender = Obj()
        receiver = QObject()
        sender.connect(SIGNAL("destroyed()"), cute_slot)
        self.assert_(sender.con_notified)
        sender.disconnect(SIGNAL("destroyed()"), cute_slot)
        self.assert_(sender.dis_notified)

    def testpyAll(self):
        sender = Obj()
        receiver = QObject()
        sender.connect(SIGNAL("foo()"), cute_slot)
        self.assert_(sender.con_notified)
        sender.disconnect(SIGNAL("foo()"), cute_slot)
        self.assert_(sender.dis_notified)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Test cases for QProcess'''

import unittest
import os
import py3kcompat as py3k

from PySide.QtCore import *

class TestQProcess (unittest.TestCase):
    def testStartDetached(self):
        value, pid = QProcess.startDetached("dir", [], os.getcwd())
        self.assertTrue(isinstance(value, bool))
        self.assertTrue(isinstance(pid, py3k.long))

    def testPid(self):
        p = QProcess()
        p.start("dir")
        p.waitForStarted()
        pid = p.pid()
        # We can't test the pid method result because it returns 0 when the
        # process isn't running
        if p.state() == QProcess.Running:
            self.assertNotEqual(pid, 0)
        else:
            print("PROCESS ALREADY DEAD :-/")

if __name__ == '__main__':
    unittest.main()



import sys
import unittest

from PySide.QtCore import QFile
from PySide.QtGui import QTabWidget
from PySide.QtUiTools import QUiLoader

from helper import UsesQApplication
from helper import adjust_filename

class TestDestruction(UsesQApplication):
    def testBug909(self):
        fileName = QFile(adjust_filename('bug_909.ui', __file__))
        loader = QUiLoader()
        main_win = loader.load(fileName)
        self.assertEqual(sys.getrefcount(main_win), 2)
        fileName.close()

        tw = QTabWidget(main_win)
        main_win.setCentralWidget(tw)
        main_win.show()

if __name__ == '__main__':
    unittest.main()



import unittest
import os
from helper import UsesQApplication

from PySide.QtGui import QWidget
from PySide.QtUiTools import QUiLoader

def get_file_path():
    for path in file_path:
        if os.path.exists(path):
            return path
    return ""

class QUioaderTeste(UsesQApplication):
    def testLoadFile(self):
        filePath = os.path.join(os.path.dirname(__file__), 'test.ui')
        loader = QUiLoader()
        parent = QWidget()
        w = loader.load(filePath, parent)
        self.assertNotEqual(w, None)

        self.assertEqual(len(parent.children()), 1)

        child = w.findChild(QWidget, "child_object")
        self.assertNotEqual(child, None)
        self.assertEqual(w.findChild(QWidget, "grandson_object"), child.findChild(QWidget, "grandson_object"))

    def testLoadFileUnicodeFilePath(self):
        filePath = str(os.path.join(os.path.dirname(__file__), 'test.ui'))
        loader = QUiLoader()
        parent = QWidget()
        w = loader.load(filePath, parent)
        self.assertNotEqual(w, None)

        self.assertEqual(len(parent.children()), 1)

        child = w.findChild(QWidget, "child_object")
        self.assertNotEqual(child, None)
        self.assertEqual(w.findChild(QWidget, "grandson_object"), child.findChild(QWidget, "grandson_object"))

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
import unittest
from PySide.QtCore import QByteArray
from PySide.QtXml import QDomDocument, QDomElement

class QDomDocumentTest(unittest.TestCase):

    def setUp(self):
        self.dom = QDomDocument()

        self.goodXmlData = QByteArray('''
        <typesystem package="PySide.QtXml">
            <value-type name="QDomDocument"/>
            <value-type name="QDomElement"/>
        </typesystem>
        ''')

        self.badXmlData = QByteArray('''
        <typesystem package="PySide.QtXml">
            <value-type name="QDomDocument">
        </typesystem>
        ''')

    def tearDown(self):
        del self.dom
        del self.goodXmlData
        del self.badXmlData

    def testQDomDocumentSetContentWithBadXmlData(self):
        '''Sets invalid xml as the QDomDocument contents.'''
        ok, errorStr, errorLine, errorColumn = self.dom.setContent(self.badXmlData, True)
        self.assertFalse(ok)
        self.assertEqual(errorStr, 'tag mismatch')
        self.assertEqual(errorLine, 4)
        self.assertEqual(errorColumn, 21)

    def testQDomDocumentSetContentWithGoodXmlData(self):
        '''Sets valid xml as the QDomDocument contents.'''
        ok, errorStr, errorLine, errorColumn = self.dom.setContent(self.goodXmlData, True)
        self.assert_(ok)
        self.assertEqual(errorStr, '')
        self.assertEqual(errorLine, 0)
        self.assertEqual(errorColumn, 0)

    def testQDomDocumentData(self):
        '''Checks the QDomDocument elements for the valid xml contents.'''

        def checkAttribute(element, attribute, value):
            self.assert_(isinstance(root, QDomElement))
            self.assertFalse(element.isNull())
            self.assert_(element.hasAttribute(attribute))
            self.assertEqual(element.attribute(attribute), value)

        ok, errorStr, errorLine, errorColumn = self.dom.setContent(self.goodXmlData, True)
        root = self.dom.documentElement()
        self.assertEqual(root.tagName(), 'typesystem')
        checkAttribute(root, 'package', 'PySide.QtXml')

        child = root.firstChildElement('value-type')
        checkAttribute(child, 'name', 'QDomDocument')

        child = child.nextSiblingElement('value-type')
        checkAttribute(child, 'name', 'QDomElement')

if __name__ == '__main__':
    unittest.main()





'''Test cases for QImage'''

import unittest

from PySide.QtGui import QImage, qRgb

from helper import UsesQApplication

class SetPixelFloat(UsesQApplication):
    '''Test case for calling setPixel with float as argument'''

    def setUp(self):
        #Acquire resources
        super(SetPixelFloat, self).setUp()
        self.color = qRgb(255, 0, 0)
        self.image = QImage(200, 200, QImage.Format_RGB32)

    def tearDown(self):
        #Release resources
        del self.color
        del self.image
        super(SetPixelFloat, self).tearDown()

    def testFloat(self):
        #QImage.setPixel(float, float, color) - Implicit conversion
        self.image.setPixel(3.14, 4.2, self.color)
        self.assertEqual(self.image.pixel(3.14, 4.2), self.color)


if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtUiTools import QUiLoader

from helper import UsesQApplication

class QUiLoaderCreation(UsesQApplication):

    def testConstructor(self):
        loader = QUiLoader()

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

'''Unit tests for QString conversion to/from Python Unicode'''

import unittest
import py3kcompat as py3k

from PySide.QtCore import QObject

class UnicodeConversion(unittest.TestCase):
    '''Test case for QString to/from Python Unicode conversion'''

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSetRegularStringRetrieveUnicode(self):
        #Set regular Python string retrieve unicode
        obj = QObject()
        obj.setObjectName('test')
        self.assertEqual(obj.objectName(), py3k.unicode_('test'))

    def testSetUnicodeRetrieveUnicode(self):
        #Set Python unicode string and retrieve unicode
        obj = QObject()
        obj.setObjectName(py3k.unicode_('ümlaut'))
        self.assertEqual(obj.objectName(), py3k.unicode_('ümlaut'))

if __name__ == '__main__':
    unittest.main()





'''Test cases for parent-child relationship'''

import unittest

from PySide.QtCore import QObject, QCoreApplication

class ChildrenCoreApplication(unittest.TestCase):
    '''Test case for calling QObject.children after creating a QCoreApp'''

    def testQCoreAppChildren(self):
        #QObject.children() after creating a QCoreApplication
        # Minimal test:
        # 1- Create QCoreApp
        # 2- Create parent and childrens
        # 3- While keeping the children alive, call parent.children()
        # 4- Delete parent
        app = QCoreApplication([])
        parent = QObject()
        children = [QObject(parent) for x in range(25)]
        # Uncomment the lines below to make the test pass
        # del children
        # del child2
        del parent # XXX Segfaults here
        self.assert_(True)


if __name__ == '__main__':
    unittest.main()




import os
import sys
import unittest

from PySide.QtCore import QUrl, QTimer
from PySide.QtGui import QApplication, QLabel
from PySide.QtWebKit import QWebPluginFactory, QWebView, QWebSettings

from helper import UsesQApplication

class PluginFactory(QWebPluginFactory):

    def plugins(self):
        plugins = []

        mime = self.MimeType()
        mime.name = 'DummyFile'
        mime.fileExtensions = ['.pys']

        plugin = self.Plugin()
        plugin.name = 'DummyPlugin'
        plugin.mimeTypes = [mime]

        plugins.append(plugin)

        return plugins

    def create(self, mimeType, url, argumentNames, argumentValues):
        if mimeType != 'application/x-dummy':
            return None

        for name, value in zip(argumentNames, argumentValues):
            if name == 'text':
                text = value
        else:
            text = "Webkit plugins!"

        widget = QLabel(text)
        return widget

class TestPlugin(UsesQApplication):

    def testPlugin(self):
        view = QWebView()
        fac = PluginFactory()
        view.page().setPluginFactory(fac)
        QWebSettings.globalSettings().setAttribute(QWebSettings.PluginsEnabled, True)

        view.load(QUrl(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'qmlplugin', 'index.html')))

        view.resize(840, 600)
        view.show()

        QTimer.singleShot(500, self.app.quit)

        self.app.exec_()


if __name__ == '__main__':
    unittest.main()




'''Test cases for QHttp'''

import unittest

from PySide.QtCore import *
from PySide.QtNetwork import *

from helper import UsesQCoreApplication
from httpd import TestServer

class HttpSignalsCase(UsesQCoreApplication):
    '''Test case for launching QHttp signals'''

    def setUp(self):
        super(HttpSignalsCase, self).setUp()
        self.httpd = TestServer()
        self.httpd.start()
        self.http = QHttp("127.0.0.1" , self.httpd.port())
        self.called = False

    def tearDown(self):
        if self.httpd:
            self.httpd.shutdown()
            del self.httpd
        self.http = None
        self.httpd = None
        super(HttpSignalsCase, self).tearDown()

    def goAway(self):
        self.httpd.shutdown()
        self.app.quit()

    def callback(self, ident):
        self.called = True
        self.goAway()

    def testDefaultArgs(self):
        #QHttp signal requestStarted signal
        # @bug 114
        self.http.requestStarted.connect(self.callback)
        self.http.get("index.html")
        self.app.exec_()
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *
import unittest
import sys

class TestBug679(unittest.TestCase):
    '''QGraphicsScene::clear() is missing'''
    def testIt(self):
        app = QApplication([])

        scene = QGraphicsScene()
        hello = scene.addText("Hello")
        scene.addText("World")

        self.assertEqual(sys.getrefcount(hello), 3)
        scene.clear()
        self.assertEqual(sys.getrefcount(hello), 2)
        self.assertEqual(len(scene.items()), 0)
        self.assertRaises(RuntimeError, hello.isVisible) # the C++ object was deleted

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-

# DBUS Server Example of use PySide with PyDBus library

import dbus
import dbus.service
import dbus.mainloop.glib
import random

from PySide.QtCore import *
from PySide.QtGui import QPushButton, QApplication

# The adaptor, MUST inherit dbus.service.Object
class DBusWidget(dbus.service.Object):
    def __init__(self, name, session):
        # export this object to dbus
        dbus.service.Object.__init__(self, name, session)

        # create a simple widget
        self.widget = QPushButton()
        self.widget.resize(200, 50)

        # To export a Qt signal as a DBus-signal, you need to connect it to a method in this class.
        # The method MUST have the signal annotation, so python-dbus will export it as a dbus-signal
        QObject.connect(self.widget, SIGNAL("clicked()"), self.clicked)
        QObject.connect(QApplication.instance(), SIGNAL("lastWindowClosed()"), self.lastWindowClosed)

    # You can export methods to dbus like you do in python-dbus.
    @dbus.service.method("com.example.SampleWidget", in_signature='', out_signature='')
    def show(self):
        self.widget.show()

    # Another method... now with a parameter
    @dbus.service.method("com.example.SampleWidget", in_signature='s', out_signature='')
    def setText(self, value):
        self.widget.setText(value)

    # Another one...
    @dbus.service.method("com.example.SampleWidget", in_signature='', out_signature='')
    def exit(self):
        qApp().quit()

    # A signal that will be exported to dbus
    @dbus.service.signal("com.example.SampleWidget", signature='')
    def clicked(self):
        pass

    # Another signal that will be exported to dbus
    @dbus.service.signal("com.example.SampleWidget", signature='')
    def lastWindowClosed(self):
        pass


if __name__ == '__main__':
    app = QApplication([])
    # Use qt/glib mainloop integration to get dbus mainloop working
    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)

    session_bus = dbus.SessionBus()
    # Export the service
    name = dbus.service.BusName("com.example.SampleService", session_bus)
    # Export the object
    widget = DBusWidget(session_bus, '/DBusWidget')

    print "Running example service."
    app.exec_()




import unittest

from PySide.QtCore import QObject

class MyBaseObject(QObject):
    def __init__(self, number):
        self.myMember = 'myMember' + number
        QObject.__init__(self)

class QObjectConstructorTest(unittest.TestCase):
    def testBug(self):
        for i in range(10):
            number = str(i)
            obj = MyBaseObject(number)
            self.assertEqual(obj.myMember, 'myMember' + number)

if __name__ == '__main__':
    unittest.main()



from PySide import QtCore, QtGui, QtDeclarative
from helper import adjust_filename, TimedQApplication
import unittest

class ProxyObject(QtCore.QObject):
    def __init__(self):
        super(ProxyObject,self).__init__()
        self._o = None
        self._receivedName = ""

    @QtCore.Slot(result='QObject*')
    def getObject(self):
        if self._o:
            return self._o

        self._o = QtCore.QObject()
        self._o.setObjectName("PySideObject")
        return self._o

    @QtCore.Slot(str)
    def receivedObject(self, name):
        self._receivedName = name
 

class TestConnectionWithInvalidSignature(TimedQApplication):

    def testSlotRetur(self):
        view = QtDeclarative.QDeclarativeView()
        proxy = ProxyObject()

        context = view.rootContext()
        context.setContextProperty("proxy", proxy)
        view.setSource(QtCore.QUrl.fromLocalFile(adjust_filename('bug_726.qml', __file__)))
        root = view.rootObject()
        button = root.findChild(QtCore.QObject, "buttonMouseArea")
        view.show()
        button.entered.emit()
        self.assertEqual(proxy._receivedName, "PySideObject")

if __name__ == '__main__':
    unittest.main()




'''Tests for QMenuBar.addAction(identifier, callback) calls'''

import unittest

from PySide.QtCore import SLOT
from PySide.QtGui import QMenuBar, QAction, QPushButton

from helper import UsesQApplication


class AddActionTest(UsesQApplication):
    '''QMenuBar addAction'''

    def tearDown(self):
        try:
            del self.called
        except AttributeError:
            pass
        super(AddActionTest, self).tearDown()

    def _callback(self):
        self.called = True

    def testBasic(self):
        '''QMenuBar.addAction(id, callback)'''
        menubar = QMenuBar()
        action = menubar.addAction("Accounts", self._callback)
        action.activate(QAction.Trigger)
        self.assert_(self.called)

    def testWithCppSlot(self):
        '''QMenuBar.addAction(id, object, slot)'''
        menubar = QMenuBar()
        widget = QPushButton()
        widget.setCheckable(True)
        widget.setChecked(False)
        action = menubar.addAction("Accounts", widget, SLOT("toggle()"))
        action.activate(QAction.Trigger)
        self.assert_(widget.isChecked())

if __name__ == '__main__':
    unittest.main()




import unittest
import sys

from PySide.QtGui import QRegion
from PySide.QtCore import QPoint
from helper import UsesQApplication

class QRegionTest(UsesQApplication):

    def testFunctionUnit(self):
        r = QRegion(0, 0, 10, 10)
        r2 = QRegion(5, 5, 10, 10)
 
        ru = r.united(r2)
        self.assert_(ru.contains(QPoint(0,0)))
        self.assert_(ru.contains(QPoint(5,5)))
        self.assert_(ru.contains(QPoint(10,10)))
        self.assert_(ru.contains(QPoint(14,14)))

if __name__ == '__main__':
    unittest.main()




''' Forced disconnection: Delete one end of the signal connection'''

import unittest
from sys import getrefcount

from PySide.QtCore import QObject, SIGNAL, SLOT

class Dummy(QObject):
    def dispatch(self):
        self.emit(SIGNAL('foo()'))

class PythonSignalRefCount(unittest.TestCase):

    def setUp(self):
        self.emitter = Dummy()

    def tearDown(self):
        self.emitter

    def testRefCount(self):
        def cb(*args):
            pass

        self.assertEqual(getrefcount(cb), 2)

        QObject.connect(self.emitter, SIGNAL('foo()'), cb)
        self.assertEqual(getrefcount(cb), 3)

        QObject.disconnect(self.emitter, SIGNAL('foo()'), cb)
        self.assertEqual(getrefcount(cb), 2)

class CppSignalRefCount(unittest.TestCase):

    def setUp(self):
        self.emitter = QObject()

    def tearDown(self):
        self.emitter

    def testRefCount(self):
        def cb(*args):
            pass

        self.assertEqual(getrefcount(cb), 2)

        QObject.connect(self.emitter, SIGNAL('destroyed()'), cb)
        self.assertEqual(getrefcount(cb), 3)

        QObject.disconnect(self.emitter, SIGNAL('destroyed()'), cb)
        self.assertEqual(getrefcount(cb), 2)

if __name__ == '__main__':
    unittest.main()




'''Function to print a colored line to terminal'''

RED='\033[0;31m%s\033[m'

def print_colored(message, color=RED):
    print color % message

if __name__ == '__main__':
    print '42 - the answer'
    print_colored("But what's the question?")
    print 'Hum?'



import unittest

from testbinding import TestObject
from PySide.QtCore import Qt
from PySide.QtGui import QKeySequence

from helper import UsesQApplication

class QVariantTest(UsesQApplication):

    def testQKeySequenceQVariantOperator(self):
        # bug #775
        ks = QKeySequence(Qt.SHIFT, Qt.CTRL, Qt.Key_P, Qt.Key_R)
        self.assertEqual(TestObject.checkType(ks), 76)

if __name__ == '__main__':
    unittest.main()



import unittest

import sys
from PySide.QtCore import QT_TR_NOOP, QT_TR_NOOP_UTF8
from PySide.QtCore import QT_TRANSLATE_NOOP, QT_TRANSLATE_NOOP3, QT_TRANSLATE_NOOP_UTF8

class QtTrNoopTest(unittest.TestCase):

    def setUp(self):
        self.txt = 'Cthulhu fhtag!'

    def tearDown(self):
        del self.txt

    def testQtTrNoop(self):
        refcnt = sys.getrefcount(self.txt)
        result = QT_TR_NOOP(self.txt)
        self.assertEqual(result, self.txt)
        self.assertEqual(sys.getrefcount(result), refcnt + 1)

    def testQtTrNoopUtf8(self):
        refcnt = sys.getrefcount(self.txt)
        result = QT_TR_NOOP_UTF8(self.txt)
        self.assertEqual(result, self.txt)
        self.assertEqual(sys.getrefcount(result), refcnt + 1)

    def testQtTranslateNoop(self):
        refcnt = sys.getrefcount(self.txt)
        result = QT_TRANSLATE_NOOP(None, self.txt)
        self.assertEqual(result, self.txt)
        self.assertEqual(sys.getrefcount(result), refcnt + 1)

    def testQtTranslateNoopUtf8(self):
        refcnt = sys.getrefcount(self.txt)
        result = QT_TRANSLATE_NOOP_UTF8(self.txt)
        self.assertEqual(result, self.txt)
        self.assertEqual(sys.getrefcount(result), refcnt + 1)

    def testQtTranslateNoop3(self):
        refcnt = sys.getrefcount(self.txt)
        result = QT_TRANSLATE_NOOP3(None, self.txt, None)
        self.assertEqual(result, self.txt)
        self.assertEqual(sys.getrefcount(result), refcnt + 1)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python

import unittest
import py3kcompat as py3k
from testbinding import TestView
from PySide.QtCore import QAbstractListModel, QObject, QModelIndex

'''Tests model/view relationship.'''

object_name = 'test object'

class MyObject(QObject):
    pass

class ListModelKeepsReference(QAbstractListModel):
    def __init__(self, parent=None):
        QAbstractListModel.__init__(self, parent)
        self.obj = MyObject()
        self.obj.setObjectName(object_name)

    def rowCount(self, parent=QModelIndex()):
        return 1

    def data(self, index, role):
        return self.obj

class ListModelDoesntKeepsReference(QAbstractListModel):
    def rowCount(self, parent=QModelIndex()):
        return 1

    def data(self, index, role):
        obj = MyObject()
        obj.setObjectName(object_name)
        return obj

class ListModelThatReturnsString(QAbstractListModel):
    def rowCount(self, parent=QModelIndex()):
        return 1

    def data(self, index, role):
        self.obj = 'string'
        return self.obj


class ModelViewTest(unittest.TestCase):

    def testListModelDoesntKeepsReference(self):
        model = ListModelDoesntKeepsReference()
        view = TestView(model)
        obj = view.getData()
        self.assertEqual(type(obj), MyObject)
        self.assertEqual(obj.objectName(), object_name)
        obj.metaObject()

    def testListModelKeepsReference(self):
        model = ListModelKeepsReference()
        view = TestView(model)
        obj = view.getData()
        self.assertEqual(type(obj), MyObject)
        self.assertEqual(obj.objectName(), object_name)

    def testListModelThatReturnsString(self):
        model = ListModelThatReturnsString()
        view = TestView(model)
        obj = view.getData()
        self.assertEqual(type(obj), py3k.unicode)
        self.assertEqual(obj, 'string')

if __name__ == '__main__':
    unittest.main()





import unittest

import os
import tempfile

from PySide.QtCore import QFile, QFileInfo

class QFileConstructor(unittest.TestCase):
    '''QFileInfo constructor with qfile'''

    def testBasic(self):
        '''QFileInfo(QFile)'''
        obj = QFileInfo(QFile())

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Test cases for QEnum and QFlags'''

import unittest

from PySide.QtCore import *

class TestEnum(unittest.TestCase):

    def testToInt(self):
        self.assertEqual(QIODevice.NotOpen, 0)
        self.assertEqual(QIODevice.ReadOnly, 1)
        self.assertEqual(QIODevice.WriteOnly, 2)
        self.assertEqual(QIODevice.ReadWrite, 1 | 2)
        self.assertEqual(QIODevice.Append, 4)
        self.assertEqual(QIODevice.Truncate, 8)
        self.assertEqual(QIODevice.Text, 16)
        self.assertEqual(QIODevice.Unbuffered, 32)

    def testToIntInFunction(self):
        self.assertEqual(str(int(QIODevice.WriteOnly)), "2")

class TestQFlags(unittest.TestCase):
    def testToItn(self):
        om = QIODevice.NotOpen

        self.assertEqual(om, QIODevice.NotOpen)
        self.assertTrue(om == 0)

        self.assertTrue(om != QIODevice.ReadOnly)
        self.assertTrue(om != 1)

    def testToIntInFunction(self):
        om = QIODevice.WriteOnly
        self.assertEqual(int(om), 2)

    def testNonExtensibleEnums(self):
        try:
            om = QIODevice.OpenMode(QIODevice.WriteOnly)
            self.assertFail()
        except:
            pass

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtGui import QWidget, QMainWindow
from helper import UsesQApplication

class QWidgetInherit(QMainWindow):
    def __init__(self):
        QWidget.__init__(self)

class QWidgetTest(UsesQApplication):

    def testInheritance(self):
        self.assertRaises(TypeError, QWidgetInherit)

class QWidgetVisible(UsesQApplication):

    def testBasic(self):
        # Also related to bug #244, on existence of setVisible'''
        widget = QWidget()
        self.assert_(not widget.isVisible())
        widget.setVisible(True)
        self.assert_(widget.isVisible())


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Test case for QObject.childEvent and QTimer.childEvent overloading'''

import unittest
from time import sleep
from PySide.QtCore import QObject, QTimer, QCoreApplication

from helper import UsesQCoreApplication

class ExtQObject(QObject):
    def __init__(self):
        QObject.__init__(self)
        self.child_event_received = False

    def childEvent(self, event):
        QObject.childEvent(self, event)
        self.child_event_received = True

class ExtQTimer(QTimer):
    def __init__(self):
        QTimer.__init__(self)
        self.child_event_received = False

    def childEvent(self, event):
        QTimer.childEvent(self, event)
        self.child_event_received = True


class TestChildEvent(UsesQCoreApplication):
    '''Test case for QObject::childEvent and QTimer::childEvent'''

    def setUp(self):
        UsesQCoreApplication.setUp(self)

    def tearDown(self):
        UsesQCoreApplication.tearDown(self)

    def testQObject(self):
        parent = ExtQObject()
        child = QObject()
        child.setParent(parent)
        self.assertTrue(parent.child_event_received)

    def testQTimer(self):
        parent = ExtQTimer()
        child = QObject()
        child.setParent(parent)
        self.assert_(parent.child_event_received)

if __name__ == '__main__':
    unittest.main()




from PySide.QtDeclarative import QDeclarativeItem, qmlRegisterType, QDeclarativeView
from PySide.QtCore import QUrl

from helper import adjust_filename, TimedQApplication
import unittest

class MyItem(QDeclarativeItem):
    COMPONENT_COMPLETE_CALLED = False
    def __init__(self,parent=None):
        super(MyItem, self).__init__(parent)
        self.setObjectName("myitem")

    def componentComplete(self):
        MyItem.COMPONENT_COMPLETE_CALLED = True
        super(MyItem, self).componentComplete()

class TestRegisterQMLType(TimedQApplication):
    def setup(self):
        TimedQApplication.setup(self, 100 * 3) # 3s

    def testSignalEmission(self):
        qmlRegisterType(MyItem, "my.item", 1, 0, "MyItem")

        view = QDeclarativeView()
        view.setSource(QUrl.fromLocalFile(adjust_filename('bug_951.qml', __file__)))

        self.app.exec_()
        self.assertTrue(MyItem.COMPONENT_COMPLETE_CALLED)

if __name__ == '__main__':
    unittest.main()




import unittest

import sys
from PySide import QtGui, QtCore
from helper import UsesQApplication

class QListWidgetTest(UsesQApplication):

    def populateList(self, lst):
        o = QtCore.QObject()
        o.setObjectName("obj")

        item = QtGui.QListWidgetItem("item0")
        item.setData(QtCore.Qt.UserRole, o)
        #item._data = o
        self.assert_(sys.getrefcount(o), 3)
        self.assert_(sys.getrefcount(item), 2)
        lst.addItem(item)
        self.assert_(sys.getrefcount(item), 3)

    def checkCurrentItem(self, lst):
        item = lst.currentItem()
        self.assert_(sys.getrefcount(item), 3)

    def checkItemData(self, lst):
        item = lst.currentItem()
        o = item.data(QtCore.Qt.UserRole)
        self.assert_(sys.getrefcount(o), 4)
        self.assertEqual(o, item._data)
        self.assert_(sys.getrefcount(o), 2)

    def testConstructorWithParent(self):
        lst = QtGui.QListWidget()
        self.populateList(lst)
        self.checkCurrentItem(lst)
        i = lst.item(0)
        self.assert_(sys.getrefcount(i), 3)

        del lst
        self.assert_(sys.getrefcount(i), 2)
        del i

    def testIt(self):
        lst = QtGui.QListWidget()
        lst.show()
        slot = lambda : lst.removeItemWidget(lst.currentItem())
        lst.addItem(QtGui.QListWidgetItem("foo"))
        QtCore.QTimer.singleShot(0, slot)
        QtCore.QTimer.singleShot(0, lst.close)
        self.app.exec_()
        self.assertEqual(lst.count(), 1)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

"""Tests covering signal emission and receiving to python slots"""

import unittest

from PySide.QtCore import QObject, SIGNAL
from helper import UsesQCoreApplication

class MyObject(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self._slotCalledCount = 0

    def mySlot(self):
        self._slotCalledCount = self._slotCalledCount + 1


class StaticMetaObjectTest(UsesQCoreApplication):

    def testSignalPropagation(self):
        o = MyObject()
        o2 = MyObject()

        # SIGNAL foo not created yet
        self.assertEqual(o.metaObject().indexOfSignal("foo()"), -1)

        o.connect(SIGNAL("foo()"), o2.mySlot)
        # SIGNAL foo create after connect
        self.assert_(o.metaObject().indexOfSignal("foo()") > 0)

        # SIGNAL does not propagate to others objects of the same type
        self.assertEqual(o2.metaObject().indexOfSignal("foo()"), -1)

        del o
        del o2
        o = MyObject()
        # The SIGNAL was destroyed with old objects
        self.assertEqual(o.metaObject().indexOfSignal("foo()"), -1)


    def testSharedSignalEmission(self):
        o = QObject()
        m = MyObject()

        o.connect(SIGNAL("foo2()"), m.mySlot)
        m.connect(SIGNAL("foo2()"), m.mySlot)
        o.emit(SIGNAL("foo2()"))
        self.assertEqual(m._slotCalledCount, 1)
        del o
        m.emit(SIGNAL("foo2()"))
        self.assertEqual(m._slotCalledCount, 2)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import Property, QObject
from PySide.QtWebKit import QWebView
from helper import TimedQApplication

class TestLambdaPropery(TimedQApplication):

    def testBug899(self):
        html = '''
        <html><body>
        <script type="text/javascript">
        document.write("<p>"+py_obj.list1+"</p>")
        document.write("<p>"+py_obj.list2+"</p>")
        </script>
        </body></html>
        '''

        class Obj(object):
            list1 = ['foo', 'bar', 'baz']
            list2 = ['fi', 'fo', 'fum']

        obj = Obj()

        wrapper_dict = {}
        for name in ('list1', 'list2'):
            getter = lambda arg=None, name=name: getattr(obj, name)
            wrapper_dict[name] = Property('QVariantList', getter)
        wrapper = type('PyObj', (QObject,), wrapper_dict)

        view = QWebView()
        view.page().mainFrame().addToJavaScriptWindowObject('py_obj', wrapper())
        view.setHtml(html)


if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import QObject, SIGNAL, Qt

class Dummy(QObject):
    """Dummy class used in this test."""
    def __init__(self, parent=None):
        QObject.__init__(self, parent)

class TestConnectionTypeSupport(unittest.TestCase):
    def callback(self, *args):
        if tuple(self.args) == args:
            self.called = True

    def testNoArgs(self):
        """Connect signal using a Qt.ConnectionType as argument"""
        obj1 = Dummy()

        QObject.connect(obj1, SIGNAL('foo'), self.callback, Qt.DirectConnection)
        self.args = tuple()
        obj1.emit(SIGNAL('foo'), *self.args)

        self.assert_(self.called)


if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtGui import *
from PySide.QtWebKit import *

class TestBug803 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])
        page = QWebPage()
        frame = page.mainFrame()
        frame.setHtml("<html><head></head><body><p>1</p><p>2</p></body></html>")
        elems = frame.findAllElements("p")
        self.assertEqual(len(elems), 2)
        self.assertEqual(elems[0].toPlainText(), "1")
        self.assertEqual(elems[1].toPlainText(), "2")

if __name__ == "__main__":
    unittest.main()



import gc
import unittest

from PySide.QtCore import qsrand

class OverflowExceptionCollect(unittest.TestCase):
    '''Test case for OverflowError exception during garbage collection. See bug #147'''

    def testOverflow(self):
        # NOTE: PyQt4 raises TypeError, but boost.python raises OverflowError
        self.assertRaises(OverflowError, qsrand, 42415335332353253)
        # should not abort if bug #147 is fixed
        gc.collect()

if __name__ == '__main__':
        unittest.main()



# -*- coding: utf-8 -*-

import unittest

from PySide.QtCore import *
from PySide.QtGui import *

class MyObject(QWidget):
    def __init__(self, parent=None):
        QWidget.__init__(self, parent)
        self._method_called = False

    @Slot()
    def on_button_clicked(self):
        self._method_called = True


class AutoConnectionTest(unittest.TestCase):

    def testConnection(self):
        app = QApplication([])

        win = MyObject()
        btn = QPushButton("click", win)
        btn.setObjectName("button")
        QMetaObject.connectSlotsByName(win)
        btn.click()
        self.assert_(win._method_called)

if __name__ == '__main__':
    unittest.main()




'''Test cases for QObject property and setProperty'''

import unittest

from PySide.QtCore import QObject, Property, Signal

class MyObjectWithNotifyProperty(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.p = 0

    def readP(self):
        return self.p

    def writeP(self, v):
        self.p = v
        self.notifyP.emit()

    notifyP = Signal()
    myProperty = Property(int, readP, fset=writeP, notify=notifyP)

class PropertyWithNotify(unittest.TestCase):
    def called(self):
        self.called_ = True

    def testNotify(self):
        self.called_ = False
        obj = MyObjectWithNotifyProperty()
        obj.notifyP.connect(self.called)
        obj.myProperty = 10
        self.assert_(self.called_)

    def testHasProperty(self):
        o = MyObjectWithNotifyProperty()
        o.setProperty("myProperty", 10)
        self.assertEqual(o.myProperty, 10)
        self.assertEqual(o.property("myProperty"), 10)


if __name__ == '__main__':
    unittest.main()



'''Test cases for __hash__'''

import unittest

from PySide.QtGui import QTreeWidgetItem
from helper import UsesQApplication

class HashableTest(UsesQApplication):

    def testQTreeWidgetItemHash(self):
        h = {}
        obj = QTreeWidgetItem()
        h[obj] = 2
        self.assert_(h.get(obj), 2)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide.QtCore import QObject, Signal

class BoundAndUnboundSignalsTest(unittest.TestCase):

    def setUp(self):
        self.methods = set(('connect', 'disconnect', 'emit'))

    def tearDown(self):
        del self.methods

    def testUnboundSignal(self):
        self.assertEqual(type(QObject.destroyed), Signal)
        self.assertFalse(self.methods.issubset(dir(QObject.destroyed)))

    def testBoundSignal(self):
        obj = QObject()
        self.assertNotEqual(type(obj.destroyed), Signal)
        self.assert_(self.methods.issubset(dir(obj.destroyed)))

if __name__ == '__main__':
    unittest.main()





import unittest

from PySide.QtCore import QObject, Signal
o = QObject()
class MyObject(QObject):
    s = Signal(int)

class CheckSignalType(unittest.TestCase):
    def testSignal(self):
        self.assertTrue(isinstance(QObject.destroyed, Signal))
        self.assertEqual(type(QObject.destroyed), Signal)

        self.assertEqual(type(o.destroyed).__name__, "SignalInstance")
        self.assertNotEqual(type(o.destroyed), Signal)

        self.assertTrue(isinstance(o.destroyed, Signal))
        self.assertTrue(isinstance(MyObject.s, Signal))
        self.assertFalse(isinstance(int, Signal))

if __name__ == '__main__':
    unittest.main()




import unittest
from copy import deepcopy

from PySide.QtCore import QByteArray, QDate, QDateTime, QTime, QLine, QLineF
from PySide.QtCore import Qt, QSize, QSizeF, QRect, QRectF, QDir, QPoint, QPointF
from PySide.QtCore import QUuid

class DeepCopyHelper:
    def testCopy(self):
        copy = deepcopy([self.original])[0]
        self.assert_(copy is not self.original)
        self.assertEqual(copy, self.original)

class QByteArrayDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QByteArray('the quick brown fox jumps over the lazy dog')


class QDateDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QDate(2010, 11, 22)


class QTimeDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QTime(11, 37, 55, 692)


class QDateTimeDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QDateTime(2010, 5, 18, 10, 24, 45, 223, Qt.LocalTime)


class QSizeDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QSize(42, 190)


class QSizeFDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QSizeF(42.7, 190.2)


class QRectDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QRect(100, 200, 300, 400)


class QRectFDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QRectF(100.33, 200.254, 300.321, 400.123)

class QLineDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QLine(1, 2, 3, 4)

class QLineFDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QLineF(1.1, 2.2, 3.3, 4.4)

class QPointDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QPoint(1, 2)

class QPointFDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QPointF(1.1, 2.2)

class QDirDeepCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QDir("./")

class QUuiCopy(DeepCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QUuid("67C8770B-44F1-410A-AB9A-F9B5446F13EE")

if __name__ == '__main__':
    unittest.main()



import sys
import unittest
from PySide import QtCore

class MyObject(QtCore.QObject):
    def __init__(self, other=None):
        QtCore.QObject.__init__(self, None)
        self._o = other

class TestDestructor(unittest.TestCase):
    def testReference(self):
        o = QtCore.QObject()
        m = MyObject(o)
        self.assertEqual(sys.getrefcount(o), 3)
        del m
        self.assertEqual(sys.getrefcount(o), 2)

if __name__ == '__main__':
    unittest.main()




'''Test cases for Reference count when the object is created in c++ side'''

import unittest

import sys
import weakref
import gc


from PySide.QtCore import Qt, QPointF
from PySide.QtGui import QApplication, QGraphicsScene, QGraphicsRectItem, QPolygonF, QGraphicsPolygonItem, QGraphicsRectItem

from helper import UsesQApplication

destroyedRect = False
destroyedPol = False

def rect_del(o):
    global destroyedRect
    destroyedRect = True

def pol_del(o):
    global destroyedPol
    destroyedPol = True

class ReferenceCount(UsesQApplication):

    def setUp(self):
        super(ReferenceCount, self).setUp()
        self.scene = QGraphicsScene()

    def tearDown(self):
        super(ReferenceCount, self).tearDown()

    def beforeTest(self):
        points = [QPointF(0, 0), QPointF(100, 100), QPointF(0, 100)]
        pol = self.scene.addPolygon(QPolygonF(points))
        self.assert_(isinstance(pol, QGraphicsPolygonItem))
        self.wrp = weakref.ref(pol, pol_del)

        #refcount need be 3 because one ref for QGraphicsScene, and one to rect obj
        self.assertEqual(sys.getrefcount(pol), 3)

    def testReferenceCount(self):
        global destroyedRect
        global destroyedPol

        self.beforeTest()
        
        rect = self.scene.addRect(10.0, 10.0, 10.0, 10.0)
        self.assert_(isinstance(rect, QGraphicsRectItem))

        self.wrr = weakref.ref(rect, rect_del)

        #refcount need be 3 because one ref for QGraphicsScene, and one to rect obj
        self.assertEqual(sys.getrefcount(rect), 3)

        del rect
        #not destroyed because one ref continue in QGraphicsScene
        self.assertEqual(destroyedRect, False)
        self.assertEqual(destroyedPol, False)

        del self.scene

        #QGraphicsScene was destroyed and this destroy internal ref to rect
        self.assertEqual(destroyedRect, True)
        self.assertEqual(destroyedPol, True)

if __name__ == '__main__':
    unittest.main()



'''Test for Bug 630 - Fails to resolve overload for QCursor(QBitmap, QBitmap, int, int)
http://bugs.openbossa.org/show_bug.cgi?id=630
'''

import unittest
from PySide.QtGui import QBitmap, QCursor, QPixmap
from helper import UsesQApplication

class TestQCursor(UsesQApplication):
    def testQCursorConstructor(self):
        bmp = QBitmap(16, 16)
        cursor = QCursor(bmp, bmp, 16, 16)

if __name__ == '__main__':
    unittest.main()





import unittest

from PySide.QtCore import SIGNAL, QTimer
from PySide.QtScript import QScriptEngine
from PySide.QtScriptTools import QScriptEngineDebugger

from helper import UsesQApplication

class DebuggerTest(UsesQApplication):

    def setUp(self):
        UsesQApplication.setUp(self)
        self.engine = QScriptEngine()
        self.debugger = QScriptEngineDebugger()
        self.has_suspended = 0
        self.has_resumed = 0
        self.count = 3

    def suspended(self):
        self.has_suspended += 1
        # Will emit evaluationResumed until there are more instructions to be run
        QTimer.singleShot(100, self.debugger.action(QScriptEngineDebugger.StepIntoAction).trigger)

    def resumed(self):
        # Will be called when debugger.state() change from Suspended to Running
        # except for the first time.
        self.has_resumed += 1

    def testBasic(self):
        '''Interrupt and resume evaluation with QScriptEngineDebugger'''

        self.debugger.attachTo(self.engine)
        self.debugger.setAutoShowStandardWindow(False)
        self.debugger.connect(SIGNAL('evaluationSuspended()'), self.suspended)
        self.debugger.connect(SIGNAL('evaluationResumed()'), self.resumed)

        self.debugger.action(QScriptEngineDebugger.InterruptAction).trigger()
        self.engine.evaluate("3+4\n2+1\n5+1")
        self.assert_(self.has_resumed >= 1)
        self.assert_(self.has_suspended >= 1)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Test case for PySide bug 814
# http://bugs.pyside.org/show_bug.cgi?id=814
# 2011-04-08 Thomas Perl <m@thp.io>
# Released under the same terms as PySide itself

from PySide.QtCore import QUrl, QAbstractListModel, QModelIndex
from PySide.QtDeclarative import QDeclarativeView

from helper import adjust_filename, TimedQApplication
import unittest

class ListModel(QAbstractListModel):
    def __init__(self):
        QAbstractListModel.__init__(self)
        self.setRoleNames({0: 'pysideModelData'})

    def rowCount(self, parent=QModelIndex()):
        return 3

    def data(self, index, role):
        if index.isValid() and role == 0:
            return 'blubb'
        return None

class TestBug814(TimedQApplication):
    def testAbstractItemModelTransferToQML(self):
        view = QDeclarativeView()
        view.setSource(QUrl.fromLocalFile(adjust_filename('bug_814.qml', __file__)))
        root = view.rootObject()
        model = ListModel()
        root.setProperty('model', model)
        view.show()

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtGui import *

class MyData(QTextBlockUserData):
    def __init__(self, data):
        QTextBlockUserData.__init__(self)
        self.data = data

    def getMyNiceData(self):
        return self.data

class TestBug652(unittest.TestCase):
    """Segfault when using QTextBlock::setUserData due to missing ownership transfer"""
    def testIt(self):
        td = QTextDocument()
        tc = QTextCursor(td)
        tc.insertText("Hello world")
        heyHo = "hey ho!"
        tc.block().setUserData(MyData(heyHo))
        self.assertEqual(type(tc.block().userData()), MyData)
        self.assertEqual(tc.block().userData().getMyNiceData(), heyHo)

        del tc
        tc = QTextCursor(td)
        blk = tc.block()
        self.assertEqual(type(blk.userData()), MyData)
        self.assertEqual(blk.userData().getMyNiceData(), heyHo)

if __name__ == "__main__":
    unittest.main()


#!/usr/bin/python
# -*- coding: utf-8 -*-

'''Unit tests for QObject's tr and trUtf8 static methods.'''

import os
import unittest
from PySide.QtCore import QObject

#from helper import UsesQCoreApplication

class QObjectTrTest(unittest.TestCase):
    '''Test case to check if QObject tr and trUtf8 static methods could be treated as instance methods.'''

    def setUp(self):
        self.obj = QObject()

    def tearDown(self):
        del self.obj

    def testTrCommonCase(self):
        #Test common case for QObject.tr
        invar1 = 'test1'
        outvar1 = self.obj.tr(invar1)
        invar2 = 'test2'
        outvar2 = self.obj.tr(invar2, 'test comment')
        self.assertEqual((invar1, invar2), (outvar1, outvar2))

    def testTrAsInstanceMethod(self):
        #Test QObject.tr as instance
        invar1 = 'test1'
        outvar1 = QObject.tr(self.obj, invar1)
        invar2 = 'test2'
        outvar2 = QObject.tr(self.obj, invar2, 'test comment')
        self.assertEqual((invar1, invar2), (outvar1, outvar2))

    def testTrUtf8CommonCase(self):
        #Test common case for QObject.trUtf8
        invar1 = 'test1'
        outvar1 = self.obj.trUtf8(invar1)
        invar2 = 'test2'
        outvar2 = self.obj.trUtf8(invar2, 'test comment')
        self.assertEqual((invar1, invar2), (outvar1, outvar2))

    def testTrUtf8AsInstanceMethod(self):
        #Test QObject.trUtf8 as instance
        invar1 = 'test1'
        outvar1 = QObject.trUtf8(self.obj, invar1)
        invar2 = 'test2'
        outvar2 = QObject.trUtf8(self.obj, invar2, 'test comment')
        self.assertEqual((invar1, invar2), (outvar1, outvar2))

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python

'''Test cases for QTimer.singleShot'''

import unittest

from PySide.QtCore import QObject, QTimer, QCoreApplication, Signal
from helper import UsesQCoreApplication

class WatchDog(QObject):
    '''Exits the QCoreApplication main loop after sometime.'''

    def __init__(self, watched):
        QObject.__init__(self)
        self.times_called = 0
        self.watched = watched

    def timerEvent(self, evt):
        self.times_called += 1
        if self.times_called == 20:
            self.watched.exit_app_cb()

class TestSingleShot(UsesQCoreApplication):
    '''Test case for QTimer.singleShot'''

    def setUp(self):
        #Acquire resources
        UsesQCoreApplication.setUp(self)
        self.watchdog = WatchDog(self)
        self.called = False

    def tearDown(self):
        #Release resources
        del self.watchdog
        del self.called
        UsesQCoreApplication.tearDown(self)

    def callback(self):
        self.called = True
        self.app.quit()

    def testSingleShot(self):
        QTimer.singleShot(100, self.callback)
        self.app.exec_()
        self.assert_(self.called)

class SigEmitter(QObject):

    sig1 = Signal()


class TestSingleShotSignal(UsesQCoreApplication):
    '''Test case for QTimer.singleShot connecting to signals'''

    def setUp(self):
        UsesQCoreApplication.setUp(self)
        self.watchdog = WatchDog(self)
        self.called = False

    def tearDown(self):
        del self.watchdog
        del self.called
        UsesQCoreApplication.tearDown(self)

    def callback(self):
        self.called = True
        self.app.quit()

    def testSingleShotSignal(self):
        emitter = SigEmitter()
        emitter.sig1.connect(self.callback)
        QTimer.singleShot(100, emitter.sig1)
        self.app.exec_()
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()




import unittest
import os
from helper import UsesQApplication

from PySide import QtGui
from PySide.QtUiTools import QUiLoader

class MyWidget(QtGui.QComboBox):
    def __init__(self, parent=None):
        QtGui.QComboBox.__init__(self, parent)

    def isPython(self):
        return True

class BugTest(UsesQApplication):
    def testCase(self):
        w = QtGui.QWidget()
        loader = QUiLoader()

        filePath = os.path.join(os.path.dirname(__file__), 'action.ui')
        result = loader.load(filePath, w)
        self.assert_(isinstance(result.actionFoo, QtGui.QAction))

    def testPythonCustomWidgets(self):
        w = QtGui.QWidget()
        loader = QUiLoader()
        loader.registerCustomWidget(MyWidget)

        filePath = os.path.join(os.path.dirname(__file__), 'pycustomwidget.ui')
        result = loader.load(filePath, w)
        self.assert_(isinstance(result.custom, MyWidget))
        self.assert_(result.custom.isPython())

    def testPythonCustomWidgetsTwice(self):
        w = QtGui.QWidget()
        loader = QUiLoader()
        loader.registerCustomWidget(MyWidget)

        filePath = os.path.join(os.path.dirname(__file__), 'pycustomwidget2.ui')
        result = loader.load(filePath, w)
        self.assert_(isinstance(result.custom, MyWidget))
        self.assert_(isinstance(result.custom2, MyWidget))
        self.assert_(result.custom.isPython())

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python

'''Connecting lambda to signals'''

import sys
import unittest

from PySide.QtCore import QObject, SIGNAL, QProcess

from helper import UsesQCoreApplication


class Dummy(QObject):

    def __init__(self, *args):
        super(Dummy, self).__init__(*args)


class BasicCase(unittest.TestCase):

    def testSimplePythonSignalNoArgs(self):
        #Connecting a lambda to a simple python signal without arguments
        obj = Dummy()
        QObject.connect(obj, SIGNAL('foo()'),
                        lambda: setattr(obj, 'called', True))
        obj.emit(SIGNAL('foo()'))
        self.assert_(obj.called)

    def testSimplePythonSignal(self):
        #Connecting a lambda to a simple python signal witharguments
        obj = Dummy()
        arg = 42
        QObject.connect(obj, SIGNAL('foo(int)'),
                        lambda x: setattr(obj, 'arg', 42))
        obj.emit(SIGNAL('foo(int)'), arg)
        self.assertEqual(obj.arg, arg)


class QtSigLambda(UsesQCoreApplication):

    qapplication = True

    def testNoArgs(self):
        '''Connecting a lambda to a signal without arguments'''
        proc = QProcess()
        dummy = Dummy()
        QObject.connect(proc, SIGNAL('started()'),
                        lambda: setattr(dummy, 'called', True))
        proc.start(sys.executable, ['-c', '""'])
        proc.waitForFinished()
        self.assert_(dummy.called)

    def testWithArgs(self):
        '''Connecting a lambda to a signal with arguments'''
        proc = QProcess()
        dummy = Dummy()
        QObject.connect(proc, SIGNAL('finished(int)'),
                        lambda x: setattr(dummy, 'called', x))
        proc.start(sys.executable, ['-c', '""'])
        proc.waitForFinished()
        self.assertEqual(dummy.called, proc.exitCode())


if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtGui import *
from PySide.QtOpenGL import *

class TestQGLWidget (unittest.TestCase):
    def testIt(self):
        """Just test if the bindTexture(*, GLenum, GLint) methods overloads exists"""
        app = QApplication([])
        img = QImage()
        w = QGLWidget()
        a = w.bindTexture(img, 0, 0) # ok if it throws nothing.. :-)





if __name__ == "__main__":
    unittest.main()



import unittest
from PySide.QtGui import QToolBar, QApplication, QAction, QToolButton

class TestLabelPixmap(unittest.TestCase):
    def testReference(self):
        toolbar = QToolBar()

        for i in xrange(20):
            toolbar.addAction(QAction("Action %d" % i, None))

        buttons = toolbar.findChildren(QToolButton, "")
        toolbar.clear()

        for b in buttons:
            self.assertRaises(RuntimeError, b.objectName)

if __name__ == '__main__':
    app = QApplication([])
    unittest.main()




'''Test cases for multiple inheritance from 2 QObjects'''

import unittest

from PySide.QtCore import QObject
from PySide.QtGui import *

from helper import UsesQApplication

class WidgetValidator(QWidget, QIntValidator):
    def __init__(self, parent=None):
        QWidget.__init__(self, parent)
        QIntValidator.__init__(self, parent)


class DoubleQObjectInheritanceTest(UsesQApplication):

    def testDouble(self):
        '''Double inheritance from QObject classes'''

        obj = WidgetValidator()

        #QObject methods
        obj.setObjectName('aaaa')
        self.assertEqual(obj.objectName(), 'aaaa')

        #QWidget methods
        obj.setVisible(False)
        self.assertFalse(obj.isVisible())

        #QIntValidator methods
        state, string, number = obj.validate('aaaa', 0)
        self.assertEqual(state, QValidator.Invalid)
        state, string, number = obj.validate('33', 0)
        self.assertEqual(state, QValidator.Acceptable)


if __name__ == '__main__':
    unittest.main()



''' Test bug 363: http://bugs.openbossa.org/show_bug.cgi?id=363'''

import sys
import unittest
from helper import UsesQApplication
from PySide import QtCore,QtGui

# Check for desktop object lifetime
class BugTest(UsesQApplication):
    def mySlot(self):
        pass

    # test if it is possible to connect with a desktop object after storing that on an auxiliar variable
    def testCase1(self):
        desktop = QtGui.QApplication.desktop()
        desktop.resized[int].connect(self.mySlot)
        self.assert_(True)

    # test if it is possible to connect with a desktop object without storing that on an auxiliar variable
    def testCase2(self):
        QtGui.QApplication.desktop().resized[int].connect(self.mySlot)
        self.assert_(True)

if __name__ == '__main__':
    unittest.main()



'''Test case for bug #442'''

from PySide import QtCore, QtGui, QtDeclarative
from helper import adjust_filename, TimedQApplication
import unittest

class TestConnectionWithInvalidSignature(TimedQApplication):
    def onButtonClicked(self):
        self.buttonClicked = True
        self.app.quit()

    def onButtonFailClicked(self):
        pass

    def testFailConnection(self):
        self.buttonClicked = False
        self.buttonFailClicked = False
        view = QtDeclarative.QDeclarativeView()
        view.setSource(QtCore.QUrl.fromLocalFile(adjust_filename('connect_python_qml.qml', __file__)))
        root = view.rootObject()
        button = root.findChild(QtCore.QObject, "buttonMouseArea")
        self.assertRaises(TypeError, QtCore.QObject.connect, [button,QtCore.SIGNAL('entered()'), self.onButtonFailClicked])
        button.entered.connect(self.onButtonClicked)
        button.entered.emit()
        view.show()
        self.app.exec_()
        self.assert_(self.buttonClicked)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Unit tests for QGLBuffer'''

import unittest

from PySide.QtCore import QByteArray
from PySide.QtOpenGL import QGLBuffer, QGLWidget
import py3kcompat as py3k
from helper import UsesQApplication

class QGLBufferTest(UsesQApplication):
    def testIt(self):
        w = QGLWidget()
        w.makeCurrent()

        b = QGLBuffer()
        b.setUsagePattern(QGLBuffer.DynamicDraw)

        self.assertTrue(b.create())
        self.assertTrue(b.bufferId() != 0)
        self.assertTrue(b.bind())

        data = QByteArray("12345")
        b.allocate(data)
        self.assertEqual(b.size(), data.size())

        m = b.map(QGLBuffer.ReadOnly)
        if m:
            self.assertEqual(m, py3k.buffer(py3k.b(data.data())))
            b.unmap()

            m = b.map(QGLBuffer.ReadWrite)
            m[3] = py3k.b('A')
            b.unmap()
            result, rdata = b.read(3, 1)
            self.assertTrue(result)
            self.assertEqual(py3k.b('A'), rdata.data())
        else:
            print(" memory mapping is not possible in this OpenGL implementation.")
        b.release()

if __name__ == '__main__':
    unittest.main()




'''Test cases for connecting signals between threads'''

import unittest

from PySide.QtCore import QThread, QObject, SIGNAL, QCoreApplication

thread_run = False

class Source(QObject):
    def __init__(self, *args):
        QObject.__init__(self, *args)

    def emit_sig(self):
        self.emit(SIGNAL('source()'))

class Target(QObject):
    def __init__(self, *args):
        QObject.__init__(self, *args)
        self.called = False

    def myslot(self):
        self.called = True

class ThreadJustConnects(QThread):
    def __init__(self, source, *args):
        QThread.__init__(self, *args)
        self.source = source
        self.target = Target()

    def run(self):
        global thread_run
        thread_run = True
        QObject.connect(self.source, SIGNAL('source()'), self.target.myslot)

        while not self.target.called:
            pass



class BasicConnection(unittest.TestCase):

    def testEmitOutsideThread(self):
        global thread_run

        app = QCoreApplication([])
        source = Source()
        thread = ThreadJustConnects(source)

        QObject.connect(thread, SIGNAL('finished()'), lambda: app.exit(0))
        thread.start()

        while not thread_run:
            pass

        source.emit_sig()

        app.exec_()
        thread.wait()

        self.assert_(thread.target.called)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide.QtCore import QObject, Signal

class ExtQObject(QObject):

    mySignal = Signal()

    def __init__(self):
        QObject.__init__(self)


class UserSignalTest(unittest.TestCase):

    def setUp(self):
        self.emitter = ExtQObject()
        self.counter = 0

    def tearDown(self):
        del self.emitter
        del self.counter

    def testConnectEmitDisconnect(self):

        def slot():
            self.counter += 1

        self.emitter.mySignal.connect(slot)

        self.assertEqual(self.counter, 0)
        self.emitter.mySignal.emit()
        self.assertEqual(self.counter, 1)
        self.emitter.mySignal.emit()
        self.assertEqual(self.counter, 2)

        self.emitter.mySignal.disconnect(slot)

        self.emitter.mySignal.emit()
        self.assertEqual(self.counter, 2)

#    def testConnectWithConfigureMethod(self):
#
#        def slot():
#            self.counter += 1
#
#        self.emitter.pyqtConfigure(mySignal=slot)
#        self.assertEqual(self.counter, 0)
#        self.emitter.mySignal.emit()
#        self.assertEqual(self.counter, 1)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test cases for QByteArray concatenation with '+' operator'''

import unittest

from PySide.QtCore import QByteArray

class QByteArrayConcatenationOperatorTest(unittest.TestCase):
    '''Test cases for QByteArray concatenation with '+' operator'''

    def testConcatQByteArrayAndPythonString(self):
        #Test concatenation of a QByteArray with a Python string, in this order
        qba = QByteArray('foo')
        result = qba + '\x00bar'
        self.assertEqual(type(result), QByteArray)
        self.assertEqual(result, 'foo\x00bar')

    def testConcatPythonStringAndQByteArray(self):
        #Test concatenation of a Python string with a QByteArray, in this order
        concat_python_string_add_qbytearray_worked = True
        qba = QByteArray('foo')
        result = 'bar\x00' + qba
        self.assertEqual(type(result), QByteArray)
        self.assertEqual(result, 'bar\x00foo')

    # NOTICE: Does not makes sense concat a unicode string with a QByteArray, because the
    # user does not know nothing about the internal representation of the unicode string.
    #def testConcatPythonUnicodeAndQByteArray(self):
        ##Test concatenation of a Python unicode object with a QByteArray, in this order
        #concat_python_unicode_add_qbytearray_worked = True
        #qba = QByteArray('foo')
        #result = None
        #try:
            #result = u'ümlaut' + qba
        #except:
            #concat_python_unicode_add_qbytearray_worked = False
        #self.assertTrue(concat_python_unicode_add_qbytearray_worked)
        #self.assertEqual(result.__class__.__name__, 'unicode')

if __name__ == '__main__':
    unittest.main()




from PySide import QtCore, QtGui, QtDeclarative
from helper import adjust_filename, TimedQApplication
import unittest

class RotateValue(QtCore.QObject):
    def __init__(self):
        super(RotateValue,self).__init__()

    @QtCore.Slot(result=int)
    def val(self):
        return 100

    def setRotation(self, v):
        self._rotation = v

    def getRotation(self):
        return self._rotation

    rotation = QtCore.Property(int, getRotation, setRotation)

class TestConnectionWithInvalidSignature(TimedQApplication):

    def testSlotRetur(self):
        view = QtDeclarative.QDeclarativeView()
        rotatevalue = RotateValue()

        timer = QtCore.QTimer()
        timer.start(2000)

        context = view.rootContext()
        context.setContextProperty("rotatevalue", rotatevalue)
        view.setSource(QtCore.QUrl.fromLocalFile(adjust_filename('bug_456.qml', __file__)))
        root = view.rootObject()
        button = root.findChild(QtCore.QObject, "buttonMouseArea")
        view.show()
        button.entered.emit()
        self.assertEqual(rotatevalue.rotation, 100)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8
from PySide.QtCore import *
from PySide.QtGui  import *

import sys

class A(QMainWindow):
    def __init__(self, parent=None):
        super(A, self).__init__(parent)
        a = QFileSystemModel(self)
        a.setRootPath(QDir.homePath())

        v = QTreeView(self)
        v.setModel(a)
        self.setCentralWidget(v)

app = QApplication([])
m = A()
m.show()
QTimer.singleShot(0, m.close)
app.exec_()



#!/usr/bin/python
'''Test cases for QEnum and QFlags'''

import unittest

from PySide.QtCore import QThread, Qt

class TestHANDLE(unittest.TestCase):
    def testIntConversion(self):
        i = 0
        h = QThread.currentThreadId()
        i = 0 + int(h)
        self.assertEqual(i, int(h))

if __name__ == '__main__':
    unittest.main()



def b(s):
    return s

def l(n):
    return long(n)

def unicode_(s):
    if type(s) == str:
        import codecs
        c = codecs.lookup('utf-8')
        s2 = c.decode(s, 'ignore')
        return s2[0]
    return u'%s' % s

unicode = unicode
unichr = unichr
long = long
buffer = buffer



'''Test cases for QObject methods'''

import unittest

from PySide.QtCore import QObject

class InheritsCase(unittest.TestCase):
    '''Test case for QObject.inherits'''

    def testCppInheritance(self):
        #QObject.inherits() for c++ classes
        #An class inherits itself
        self.assert_(QObject().inherits('QObject'))

    def testPythonInheritance(self):
        #QObject.inherits() for python classes

        class Dummy(QObject):
            #Dummy class
            pass

        self.assert_(Dummy().inherits('QObject'))
        self.assert_(Dummy().inherits('Dummy'))
        self.assert_(not Dummy().inherits('FooBar'))

    def testPythonMultiInheritance(self):
        #QObject.inherits() for multiple inheritance
        # QObject.inherits(classname) should fail if classname isn't a
        # QObject subclass

        class Parent(object):
            #Dummy parent
            pass
        class Dummy(QObject, Parent):
            #Dummy class
            pass

        self.assert_(Dummy().inherits('QObject'))
        self.assert_(not Dummy().inherits('Parent'))

    def testSetAttributeBeforeCallingInitOnQObjectDerived(self):
        '''Test for bug #428.'''
        class DerivedObject(QObject):
            def __init__(self):
                self.member = 'member'
                QObject.__init__(self)
        obj0 = DerivedObject()
        # The second instantiation of DerivedObject will generate an exception
        # that will not come to surface immediately.
        obj1 = DerivedObject()
        # The mere calling of the object method causes
        # the exception to "reach the surface".
        obj1.objectName()

    def testMultipleInheritance(self):
        def declareClass():
            class Foo(object, QObject):
                pass

        self.assertRaises(TypeError, declareClass)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

''' Test the QShortcut constructor'''

import unittest
import sys

from PySide import QtGui, QtCore

class Foo(QtGui.QWidget):
    def __init__(self):
        QtGui.QWidget.__init__(self)
        self.ok = False
        self.copy = False

    def slot_of_foo(self):
        self.ok = True

    def slot_of_copy(self):
        self.copy = True

class MyShortcut(QtGui.QShortcut):
    def __init__(self, keys, wdg, slot):
        QtGui.QShortcut.__init__(self, keys, wdg, slot)

    def emit_signal(self):
        self.emit(QtCore.SIGNAL("activated()"))

class QAppPresence(unittest.TestCase):

    def testQShortcut(self):
        self.qapp = QtGui.QApplication([])
        f = Foo()

        self.sc = MyShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return), f, f.slot_of_foo)
        self.scstd = MyShortcut(QtGui.QKeySequence.Copy, f, f.slot_of_copy)
        QtCore.QTimer.singleShot(0, self.init);
        self.qapp.exec_()
        self.assertEquals(f.ok, True)
        self.assertEquals(f.copy, True)

    def init(self):
        self.sc.emit_signal();
        self.scstd.emit_signal();
        self.qapp.quit()

if __name__ == '__main__':
    unittest.main()



''' unit test for BUG #1063 '''

import unittest
import tempfile
from PySide import QtCore
import os
import py3kcompat as py3k

class QTextStreamTestCase(unittest.TestCase):
    def setUp(self):
        self.temp_file = tempfile.NamedTemporaryFile(delete=False)
        self.temp_file.close()
        self.f = QtCore.QFile(self.temp_file.name)
        self.f.open(QtCore.QIODevice.WriteOnly)
        self.strings = (py3k.unicode_('foo'), py3k.unicode_('bar'))
        self.stream = QtCore.QTextStream(self.f)

    def testIt(self):
        for s in self.strings:
            self.stream << s

        self.f.close()

        # make sure we didn't get an empty file
        self.assertNotEqual(QtCore.QFile(self.temp_file.name).size(), 0)

        os.unlink(self.temp_file.name)

if __name__ == "__main__":
    unittest.main()



from PySide import QtCore, QtDeclarative

import unittest
from helper import adjust_filename, UsesQApplication


class TestBug(UsesQApplication):
    def testQMLFunctionCall(self):
        ownerData = QtDeclarative.QDeclarativePropertyMap()
        ownerData.insert('name', 'John Smith')
        ownerData.insert('phone', '555-5555')
        ownerData.insert('newValue', '')

        view = QtDeclarative.QDeclarativeView()
        ctxt = view.rootContext()
        ctxt.setContextProperty('owner', ownerData)
        view.setSource(QtCore.QUrl.fromLocalFile(adjust_filename('bug_997.qml', __file__)))
        view.show()
        QtCore.QTimer.singleShot(1000, self.app.quit)
        self.app.exec_()
        self.assertEqual(ownerData.value('newName'), ownerData.value('name'))

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *

app = QApplication([])

scene = QGraphicsScene()

# don't segfault due to lack of keepReferenceCall
textEdit = scene.addWidget(QTextEdit())

layout = QGraphicsLinearLayout()
layout.addItem(textEdit)

view = QGraphicsView(scene)
view.show()



#!/usr/bin/python

from sys import getrefcount
import unittest
from PySide.QtCore import QObject, SIGNAL

class SignalManagerRefCount(unittest.TestCase):
    """Simple test case to check if the signal_manager is erroneously incrementing the object refcounter"""

    def testObjectRefcount(self):
        """Emission of QObject.destroyed() to a python slot"""
        def callback():
            pass
        obj = QObject()
        refcount = getrefcount(obj)
        QObject.connect(obj, SIGNAL('destroyed()'), callback)
        self.assertEqual(refcount, getrefcount(obj))
        QObject.disconnect(obj, SIGNAL('destroyed()'), callback)
        self.assertEqual(refcount, getrefcount(obj))

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
import unittest
from PySide.QtCore import *

class QAnimationGroupTest(unittest.TestCase):

    def testBasic(self):
        app = QCoreApplication([])

        panim = QParallelAnimationGroup()
        sanim = QSequentialAnimationGroup()
        panim.addAnimation(sanim)

        self.assertEqual(sanim.parent(), panim)

        panim.clear()

        self.assertRaises(RuntimeError, lambda :sanim.parent())

        QTimer.singleShot(100, app.quit)
        app.exec_()

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide import QtCore, QtWebKit

from helper import UsesQApplication

class QWebPageHeadless(QtWebKit.QWebPage):
    # FIXME: This is not working, the slot is not overriden!
    # http://doc.qt.nokia.com/4.7-snapshot/qwebpage.html#shouldInterruptJavaScript
    @QtCore.Slot()
    def shouldInterruptJavaScript(self):
        self._interrupted = True
        QtCore.QTimer.singleShot(300, self._app.quit)
        return True

class TestSlotOverride(UsesQApplication):
    def testFunctionCall(self):
        page = QWebPageHeadless()
        page._interrupted = False
        page._app = self.app
        page.mainFrame().setHtml('<script>while(1);</script>')
        self.app.exec_()
        self.assertTrue(page._interrupted)

if __name__ == '__main__':
    unittest.main()



from PySide.QtGui import QStringListModel
from PySide.QtCore import QModelIndex
import unittest

class TestQAbstractItemModelSignals(unittest.TestCase):
    def sigCallback(self, index, r, c):
        self._called = True

    def testSignals(self):
        self._called = False
        m = QStringListModel()
        m.rowsAboutToBeInserted[QModelIndex,int,int].connect(self.sigCallback)
        m.insertRows(0, 3)
        self.assert_(self._called)

if __name__ == '__main__':
    unittest.main()



from PySide.QtGui import *
from PySide.QtCore import *
import os

if "DISPLAY" in os.environ:
    del os.environ["DISPLAY"]

app = QApplication([], False)
QTimer.singleShot(0, app.quit)
app.exec_()






#!/usr/bin/python
# -*- coding: utf-8 -*-

'''Unit tests to test QTranslator and translation in general.'''

import os
import unittest
import py3kcompat as py3k
from PySide.QtCore import QObject, QTranslator, QCoreApplication

from helper import UsesQCoreApplication

class TranslationTest(UsesQCoreApplication):
    '''Test case for Qt translation facilities.'''

    def setUp(self):
        super(TranslationTest, self).setUp()
        self.trdir = os.path.join(os.path.dirname(__file__), 'translations')

    def testLatin(self):
        #Set string value to Latin
        translator = QTranslator()
        translator.load(os.path.join(self.trdir, 'trans_latin.qm'))
        self.app.installTranslator(translator)

        obj = QObject()
        obj.setObjectName(obj.tr('Hello World!'))
        self.assertEqual(obj.objectName(), py3k.unicode_('Orbis, te saluto!'))

    def testRussian(self):
        #Set string value to Russian
        translator = QTranslator()
        translator.load(os.path.join(self.trdir, 'trans_russian.qm'))
        self.app.installTranslator(translator)

        obj = QObject()
        obj.setObjectName(obj.tr('Hello World!'))
        self.assertEqual(obj.objectName(), py3k.unicode_('привет мир!'))

    def testUtf8(self):
        translator = QTranslator()
        translator.load(os.path.join(self.trdir, 'trans_russian.qm'))
        self.app.installTranslator(translator)

        obj = QObject()
        obj.setObjectName(obj.trUtf8('Hello World!'))
        self.assertEqual(obj.objectName(), py3k.unicode_('привет мир!'))

    def testTranslateWithNoneDisambiguation(self):
        value = 'String here'
        obj = QCoreApplication.translate('context', value, None, QCoreApplication.UnicodeUTF8)
        self.assertTrue(isinstance(obj, py3k.unicode))
        self.assertEqual(obj, value)

if __name__ == '__main__':
    unittest.main()




"""
  This script is based on Python2.6 Ubuntu package script:
  Copyright (C) 2009 Matthias Klose <doko@debian.org>
  Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public License
  version 2.1 as published by the Free Software Foundation. Please
  review the following information to ensure the GNU Lesser General
  Public License version 2.1 requirements will be met:
  http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
   02110-1301 USA
"""
#! /usr/bin/python

import formatter, htmllib
import os, sys, re

class PyHTMLParser(htmllib.HTMLParser):
    pages_to_include = set(('index.html', 'PySide/QtHelp/index.html', 'PySide/QtSvg/index.html',
                        'PySide/QtGui/index.html', 'PySide/QtNetwork/index.html', 'PySide/QtWebKit/index.html',
                        'PySide/QtUiTools/index.html', 'PySide/QtXml/index.html', 'PySide/QtCore/index.html',
                        'PySide/QtScriptTools/index.html', 'PySide/QtOpenGL/index.html', 'PySide/QtScript/index.html',
                        'PySide/QtSql/index.html', 'howto-build/index.html'))

    def __init__(self, formatter, basedir, fn, indent, parents=set()):
        htmllib.HTMLParser.__init__(self, formatter)
        self.basedir = basedir
        self.dir, self.fn = os.path.split(fn)
        self.data = ''
        self.parents = parents
        self.link = {}
        self.indent = indent
        self.last_indent = indent - 1
        self.sub_indent = 0
        self.sub_count = 0
        self.next_link = False

    def process_link(self):
        new_href = os.path.join(self.dir, self.link['href'])
        text = self.link['text']
        indent = self.indent + self.sub_indent
        if self.last_indent == indent:
            print '%s</sub>' % ('  ' * self.last_indent)
            self.sub_count -= 1
        print '%s<sub link="%s" name="%s">' % ('  ' * indent, new_href, text)
        self.sub_count += 1
        self.last_indent = self.indent + self.sub_indent

    def start_li(self, attrs):
        self.sub_indent += 1
        self.next_link = True

    def end_li(self):
        indent = self.indent + self.sub_indent
        if self.sub_count > 0:
            print '%s</sub>' % ('  ' * self.last_indent)
            self.sub_count -= 1
            self.last_indent -= 1
        self.sub_indent -= 1

    def start_a(self, attrs):
        self.link = {}
        for attr in attrs:
            self.link[attr[0]] = attr[1]
        self.data = ''

    def end_a(self):
        process = False
        text = self.data.replace('\t', '').replace('\n', ' ').replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
        self.link['text'] = text
        # handle a tag without href attribute
        try:
            href = self.link['href']
        except KeyError:
            return

        abs_href = os.path.join(self.basedir, href)
        if abs_href in self.parents:
            return
        if href.startswith('..') or href.startswith('http:') \
               or href.startswith('mailto:') or href.startswith('news:'):
            return
        if href in ('', 'about.html', 'modindex.html', 'genindex.html', 'glossary.html',
                    'search.html', 'contents.html', 'download.html', 'bugs.html',
                    'license.html', 'copyright.html'):
            return

        if self.link.has_key('class'):
            if self.link['class'] in ('biglink'):
                process = True
            if self.link['class'] in ('reference external'):
                if self.next_link:
                    process = True
                    next_link = False

        if process == True:
            self.process_link()
            if href in self.pages_to_include:
                self.parse_file(os.path.join(self.dir, href))

    def finish(self):
        if self.sub_count > 0:
            print '%s</sub>' % ('  ' * self.last_indent)

    def handle_data(self, data):
        self.data += data

    def parse_file(self, href):
        # TODO basedir bestimmen
        parent = os.path.join(self.basedir, self.fn)
        self.parents.add(parent)
        parser = PyHTMLParser(formatter.NullFormatter(),
                              self.basedir, href, self.indent + 1,
                              self.parents)
        text = file(self.basedir + '/' + href).read()
        parser.feed(text)
        parser.finish()
        parser.close()
        if parent in self.parents:
            self.parents.remove(parent)

class PyIdxHTMLParser(htmllib.HTMLParser):
    def __init__(self, formatter, basedir, fn, indent):
        htmllib.HTMLParser.__init__(self, formatter)
        self.basedir = basedir
        self.dir, self.fn = os.path.split(fn)
        self.data = ''
        self.link = {}
        self.indent = indent
        self.active = False
        self.indented = False
        self.nolink = False
        self.header = ''
        self.last_letter = 'Z'
        self.last_text = ''

    def process_link(self):
        new_href = os.path.join(self.dir, self.link['href'])
        text = self.link['text']
        if not self.active:
            return
        if text.startswith('['):
            return
        if self.link.get('rel', None) in ('prev', 'parent', 'next', 'contents', 'index'):
            return
        if self.indented:
            text = self.last_text + ' ' + text
        else:
            # Save it in case we need it again
            self.last_text = re.sub(' \([\w\-\.\s]+\)', '', text)
        indent = self.indent
        print '%s<function link="%s" name="%s"/>' % ('  ' * indent, new_href, text)

    def start_dl(self, attrs):
        if self.last_text:
            # Looks like we found the second part to a command
            self.indented = True

    def end_dl(self):
        self.indented = False

    def start_dt(self, attrs):
        self.data = ''
        self.nolink = True

    def end_dt(self):
        if not self.active:
            return
        if self.nolink == True:
            # Looks like we found the first part to a command
            self.last_text = re.sub(' \([\w\-\.\s]+\)', '', self.data)
            self.nolink = False

    def start_h2(self, attrs):
        for k, v in attrs:
            if k == 'id':
                self.header = v
                if v == '_':
                    self.active = True

    def start_td(self, attrs):
        self.indented = False
        self.last_text = ''

    def start_table(self, attrs):
        pass

    def end_table(self):
        if self.header == self.last_letter:
            self.active = False

    def start_a(self, attrs):
        self.nolink = False
        self.link = {}
        for attr in attrs:
            self.link[attr[0]] = attr[1]
        self.data = ''

    def end_a(self):
        text = self.data.replace('\t', '').replace('\n', ' ').replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
        self.link['text'] = text
        # handle a tag without href attribute
        try:
            href = self.link['href']
        except KeyError:
            return
        self.process_link()

    def handle_data(self, data):
        self.data += data

def main():
    base = sys.argv[1]
    fn = sys.argv[2]

    parser = PyHTMLParser(formatter.NullFormatter(), base, fn, indent=0)
    print '<?xml version="1.0" encoding="iso-8859-1"?>'
    print '<book title="PySide %s Documentation" name="PySide" version="%s" link="index.html">' % (sys.argv[3], sys.argv[3])
    print '<chapters>'
    parser.parse_file(fn)
    print '</chapters>'

    print '<functions>'

    fn = 'genindex.html'
    parser = PyIdxHTMLParser(formatter.NullFormatter(), base, fn, indent=1)
    text = file(base + '/' + fn).read()
    parser.feed(text)
    parser.close()

    print '</functions>'
    print '</book>'

main()




import unittest

from PySide.QtCore import *
from PySide import phonon

from helper import UsesQCoreApplication

class CapabilitiesTest(UsesQCoreApplication):
    def testFromIndex(self):
        devices = phonon.Phonon.BackendCapabilities.availableAudioOutputDevices()
        for device in devices:
            self.assert_(isinstance(device, phonon.Phonon.AudioOutputDevice))
            other = phonon.Phonon.AudioOutputDevice.fromIndex(device.index())
            self.assertEqual(device.name(), other.name())
            self.assertEqual(device.index(), other.index())

if __name__ == '__main__':
    unittest.main()



import weakref
import unittest

from PySide.QtCore import QObject, Property

class MyObject(QObject):
    def __init__(self):
        QObject.__init__(self)
        self._value = None

    @Property(int)
    def value(self):
        return self._value

    @value.setter
    def valueSet(self, value):
        self._value = value


class PropertyTest(unittest.TestCase):
    def destroyCB(self, obj):
        self._obDestroyed = True

    def testDecorator(self):
        self._obDestroyed = False
        o = MyObject()
        weak = weakref.ref(o, self.destroyCB)
        o.value = 10
        self.assertEqual(o._value, 10)
        self.assertEqual(o.value, 10)
        del o
        self.assertTrue(self._obDestroyed)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtGui import *

class TestBug546(unittest.TestCase):

    """Test to check a crash at exit"""
    def testIt(self):
        app = QApplication([])
        textEdit = QPlainTextEdit()
        completer = QCompleter(("foo", "bar"), textEdit)
        completer.setWidget(textEdit)

if __name__=='__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Tests for static methos conflicts with class methods'''

import unittest

from PySide.QtCore import *

class Foo(QFile):
  pass

class DynObject(QObject):
    def slot(self):
        pass

class qmetaobject_test(unittest.TestCase):
    """
    def test_QMetaObject(self):
        qobj = QObject()
        qobj_metaobj = qobj.metaObject()
        self.assertEqual(qobj_metaobj.className(), "QObject")

        obj = QFile()
        m = obj.metaObject()
        self.assertEqual(m.className(), "QFile")
        self.assertNotEqual(m.methodCount(), qobj_metaobj.methodCount())

        obj = Foo()
        m = obj.metaObject()
        self.assertEqual(m.className(), "Foo")
        f = QFile()
        fm = f.metaObject()
        self.assertEqual(m.methodCount(), fm.methodCount())
    """        

    def test_DynamicSlotSignal(self):
        o = DynObject()
        o2 = QObject()

        o.connect(o2, SIGNAL("bars()"), o.slot)
        self.assertTrue(o2.metaObject().indexOfMethod("bars()") > -1)
        #self.assertTrue(o.metaObject().indexOfMethod("bar()") == -1)
        #self.assertTrue(o.metaObject().indexOfMethod("slot()") > -1)

        #slot_index = o.metaObject().indexOfMethod("slot()")

        #o.connect(o, SIGNAL("foo()"), o2, SIGNAL("bar()"))
        #signal_index = o.metaObject().indexOfMethod("foo()");

        #self.assert_(slot_index != signal_index)


if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-

import unittest
from PySide.QtCore import *

class MyModel (QAbstractListModel):
    pass

class Foo:
    pass

class TestQModelIndexInternalPointer(unittest.TestCase):

    def testInternalPointer(self):
        m = MyModel()
        foo = Foo()
        idx = m.createIndex(0,0, foo)

    def testPassQPersistentModelIndexAsQModelIndex(self):
        # Related to bug #716
        m = MyModel()
        idx = QPersistentModelIndex()
        m.span(idx)


if __name__ == '__main__':
    unittest.main()




from PySide.QtCore import QObject

import unittest


class TestBug987(unittest.TestCase):
    def callback(self):
        pass

    def testInvalidDisconnection(self):
        o = QObject()
        self.assertRaises(RuntimeError, o.destroyed.disconnect, self.callback)

if __name__ == '__main__':
    unittest.main()



import gc
import unittest

from PySide.QtCore import QTextCodec

class TestCodecGetters(unittest.TestCase):

    def testCodecsNames(self):
        for codec_name in QTextCodec.availableCodecs():
            codec = QTextCodec.codecForName(codec_name)
            self.assert_(type(codec), QTextCodec)

    def testCodecsMibs(self):
        for codec_num in QTextCodec.availableMibs():
            codec = QTextCodec.codecForMib(codec_num)
            self.assert_(type(codec), QTextCodec)


if __name__ == '__main__':
        unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test cases for QCoreApplication.instance static method'''

import unittest

from PySide.QtCore import QCoreApplication

class QCoreApplicationInstanceTest(unittest.TestCase):
    '''Test cases for QCoreApplication.instance static method'''

    def testQCoreApplicationInstance(self):
        #Tests QCoreApplication.instance()
        self.assertEqual(QCoreApplication.instance(), None)
        app = QCoreApplication([])
        self.assertEqual(QCoreApplication.instance(), app)

if __name__ == '__main__':
    unittest.main()





'''Test cases for QHttp'''

import unittest

from PySide.QtCore import *
from PySide.QtNetwork import *

from helper import UsesQCoreApplication
from httpd import TestServer

class AccessManagerCase(UsesQCoreApplication):

    def setUp(self):
        super(AccessManagerCase, self).setUp()
        self.httpd = TestServer()
        self.httpd.start()
        self.called = False

    def tearDown(self):
        super(AccessManagerCase, self).tearDown()
        if self.httpd:
            self.httpd.shutdown()
            self.httpd = None

    def goAway(self):
        self.httpd.shutdown()
        self.app.quit()
        self.httpd = None

    def slot_replyFinished(self, reply):
        self.assertEqual(type(reply), QNetworkReply)
        self.called = True
        self.goAway()

    def testNetworkRequest(self):
        manager = QNetworkAccessManager()
        manager.finished.connect(self.slot_replyFinished)
        manager.get(QNetworkRequest(QUrl("http://127.0.0.1:%s" % self.httpd.port())))
        self.app.exec_()
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()



# Test case for PySide bug 829
# Thomas Perl <thp.io/about>; 2011-04-16

import unittest
from PySide.QtCore import QSettings
import tempfile

class QVariantConversions(unittest.TestCase):
    def testDictionary(self):
        confFile = tempfile.NamedTemporaryFile(delete=False)
        s = QSettings(confFile.name, QSettings.IniFormat)
        # Save value
        s.setValue('x', {1: 'a'})
        s.sync()
        del s

        # Restore value
        s = QSettings(confFile.name, QSettings.IniFormat)
        self.assertEqual(s.value('x'), {1: 'a'})

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import QPoint
from PySide.QtGui import QMatrix, QMatrix4x4


def qpointTimesQMatrix(point, matrix):
    '''As seen in "QPoint QMatrix::map(const QPoint &p) const" C++ implementation.'''
    return QPoint(matrix.m11() * point.x() + matrix.m21() * point.y() + matrix.dx(),
                  matrix.m12() * point.x() + matrix.m22() * point.y() + matrix.dy())

class QMatrixTest(unittest.TestCase):

    def testMatrix(self):
        matrix = QMatrix(11, 12, 21, 22, 100, 200)
        point = QPoint(3, 3)
        self.assertEqual(point * matrix, qpointTimesQMatrix(point, matrix))

    def testMatrixWithWrongType(self):
        matrix = QMatrix(11, 12, 21, 22, 100, 200)
        point = QPoint(3, 3)
        self.assertRaises(TypeError, matrix.__mul__, point)

    def testMatrix4x4(self):
        self.assertRaises(TypeError, QMatrix4x4, [0.0, 1.0, 2.0, 3.0])
        self.assertRaises(TypeError, QMatrix4x4, [0.0, 1.0, 2.0, 'I',
                                                  4.0, 5.0, 6.0, 7.0,
                                                  8.0, 9.0, 'N', 11.0,
                                                  12.0, 'd', 14.0, 'T'])

        my_data = [0.0, 1.0, 2.0, 3.0,
                   4.0, 5.0, 6.0, 7.0,
                   8.0, 9.0, 10.0, 11.0,
                   12.0, 13.0, 14.0, 15.0]
        my_datac = [0.0, 4.0, 8.0, 12.0,
                    1.0, 5.0, 9.0, 13.0,
                    2.0, 6.0, 10.0, 14.0,
                    3.0, 7.0, 11.0, 15.0]

        m = QMatrix4x4(my_data)
        d = m.data()
        self.assert_(my_datac, d)

        d = m.copyDataTo()
        self.assert_(my_data == list(d))

    def testMatrixMapping(self):
        m = QMatrix(1.0, 2.0, 1.0, 3.0, 100.0, 200.0)
        res = m.map(5, 5)
        self.assertAlmostEqual(res[0], 5 * 1.0 + 5 * 1.0 + 100.0)
        self.assertAlmostEqual(res[1], 5 * 2.0 + 5 * 3.0 + 200.0)
        res = m.map(5.0, 5.0)
        self.assertAlmostEqual(res[0], 5.0 * 1.0 + 5.0 * 1.0 + 100.0)
        self.assertAlmostEqual(res[1], 5.0 * 2.0 + 5.0 * 3.0 + 200.0)

if __name__ == '__main__':
    unittest.main()




''' Test bug 389: http://bugs.openbossa.org/show_bug.cgi?id=389'''

import sys
import unittest
from helper import UsesQApplication
from PySide import QtCore,QtGui

class BugTest(UsesQApplication):
    def testCase(self):
        s = QtGui.QWidget().style()
        i = s.standardIcon(QtGui.QStyle.SP_TitleBarMinButton)
        self.assertEqual(type(i), QtGui.QIcon)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import os
from PySide.QtCore import QAbstractFileEngineIterator, QAbstractFileEngine, QAbstractFileEngineHandler, QDir


class TestFSIterator(QAbstractFileEngineIterator):
    def __init__(self, parent, filters, filterNames):
        QAbstractFileEngineIterator.__init__(self, filters, filterNames)
        self.index = -1
        self._list = ['.', '..']
        if parent == '/bup':
            self._list += ['A', 'B', 'C']

    def next(self):
        self.index += 1
        return self.currentFileName()

    def hasNext(self):
        return (self.index + 1) < len(self._list)

    def currentFileName(self):
        if self.index < len(self._list):
            return self._list[self.index]
        return None


class TestFS(QAbstractFileEngine):
    def __init__(self, path):
        QAbstractFileEngine.__init__(self)
        self.path = path

    def beginEntryList(self, filters, filterNames):
        return TestFSIterator(self.path, filters, filterNames)

    def fileFlags(self, _ = QAbstractFileEngine.FileInfoAll):
        return QAbstractFileEngine.ExistsFlag\
               |QAbstractFileEngine.ReadOwnerPerm\
               |QAbstractFileEngine.ReadUserPerm\
               |QAbstractFileEngine.ReadGroupPerm\
               |QAbstractFileEngine.ReadOtherPerm\
               |QAbstractFileEngine.DirectoryType

    def fileName(self, path=QAbstractFileEngine.DefaultName):
        if path == QAbstractFileEngine.DefaultName:
            return self.path
        return os.path.basename(self.path)

    def setFileName(self, path):
        self.path = path

class TestFSHandler(QAbstractFileEngineHandler):
    def __init__(self):
        QAbstractFileEngineHandler.__init__(self)

    def create(self, path):
        if path.startswith('/bup'):
            return TestFS(path)
        return None

class QAbstractFileEngineTest(unittest.TestCase):

    def testBeginEntryList(self):
        obj = TestFSHandler()
        qdir = QDir('/bup')
        for n1, n2 in zip(qdir.entryList(), ['.', '..', 'A', 'B', 'C']):
            self.assertEqual(n1, n2)
        self.assertEqual(len(qdir.entryList()), 5)


if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import QEasingCurve

def myFunction(progress):
    if progress == 1.0:
        return 100.0
    else:
        return -100.0

class TestQEasingCurve(unittest.TestCase):
    def testCustomType(self):
        ec = QEasingCurve()
        ec.setCustomType(myFunction)
        self.assertEqual(ec.valueForProgress(1.0), 100.0)
        self.assertEqual(ec.valueForProgress(0.5), -100.0)

    def testObjectCleanup(self):
        for i in range(100):
            ec = QEasingCurve()
            ec.setCustomType(myFunction)
            self.assertEqual(ec.valueForProgress(1.0), 100.0)
            self.assertEqual(ec.valueForProgress(0.5), -100.0)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import *

class MyTimer (QTimer):
    def __init__(self):
        QTimer.__init__(self)
        self.startCalled = False

    @Slot()
    def slotUsedToIncreaseMethodOffset(self):
        pass

class MyTimer2 (MyTimer):

    @Slot()
    def slotUsedToIncreaseMethodOffset2(self):
        pass

    def start(self):
        self.startCalled = True
        QCoreApplication.instance().quit()

class TestBug1019 (unittest.TestCase):
    def testIt(self):
        app = QCoreApplication([])
        t = MyTimer2()
        QTimer.singleShot(0, t.start)
        app.exec_()
        self.assertTrue(t.startCalled)

if __name__ == "__main__":
    unittest.main()




import unittest
import colorsys

from PySide.QtCore import SIGNAL
from PySide.QtGui import QPushButton, QApplication


class Test (QApplication) :
    def __init__(self, argv) :
        super(Test, self).__init__(argv)
        self._called = False
        
    def called(self):
        self._called = True        


class QApplicationSignalsTest(unittest.TestCase):
    def testQuit(self):
        app = Test([])
        button = QPushButton("BUTTON")
        app.connect(button, SIGNAL("clicked()"), app.called)
        button.click()
        self.assert_(app._called)
        
if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import QObject, SIGNAL

class QObjectDestroyed(unittest.TestCase):
    """Very simple test case for the destroyed() signal of QObject"""

    def setUp(self):
        self.called = False

    def destroyed_cb(self):
        self.called = True

    def testDestroyed(self):
        """Emission of QObject.destroyed() to a python slot"""
        obj = QObject()
        QObject.connect(obj, SIGNAL('destroyed()'), self.destroyed_cb)
        del obj
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide import QtGui

from helper import UsesQApplication

class QListWidgetItemConstructor(UsesQApplication):

    def setUp(self):
        super(QListWidgetItemConstructor, self).setUp()
        self.widgetList = QtGui.QListWidget()

    def tearDown(self):
        del self.widgetList
        super(QListWidgetItemConstructor, self).tearDown()

    def testConstructorWithParent(self):
        # Bug 235 - QListWidgetItem constructor not saving ownership
        QtGui.QListWidgetItem(self.widgetList)
        item = self.widgetList.item(0)
        self.assertEqual(item.listWidget(), self.widgetList)

    def testConstructorWithNone(self):
        # Bug 452 - QListWidgetItem() not casting NoneType to null correctly.
        item = QtGui.QListWidgetItem(None, 123)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtGui import QSplitter

from helper import UsesQApplication

class QSplitterTest(UsesQApplication):

    def testGetRange(self):
        splitter = QSplitter()
        _min, _max = splitter.getRange(0)
        self.assert_(isinstance(_min, int))
        self.assert_(isinstance(_max, int))

if __name__ == "__main__":
   unittest.main()




import unittest
import py3kcompat as py3k

from PySide.QtCore import QSizeF, QTimer
from PySide.QtGui import QTextFormat, QTextCharFormat, QTextEdit, QPyTextObject
from helper import UsesQApplication

class Foo(QPyTextObject):
    called = False

    def intrinsicSize(self, doc, posInDocument, format):
        Foo.called = True
        return QSizeF(10, 10)

    def drawObject(self, painter, rect, doc, posInDocument, format):
        pass

class QAbstractTextDocumentLayoutTest(UsesQApplication):

    objectType = QTextFormat.UserObject + 1

    def foo(self):
        fmt = QTextCharFormat()
        fmt.setObjectType(QAbstractTextDocumentLayoutTest.objectType)

        cursor = self.textEdit.textCursor()
        cursor.insertText(py3k.unichr(0xfffc), fmt)
        self.textEdit.setTextCursor(cursor)
        self.textEdit.close()

    def testIt(self):

        self.textEdit = QTextEdit()
        self.textEdit.show()

        interface = Foo()
        self.textEdit.document().documentLayout().registerHandler(QAbstractTextDocumentLayoutTest.objectType, interface)

        QTimer.singleShot(0, self.foo)
        self.app.exec_()

        self.assertTrue(Foo.called)

if __name__ == "__main__":
    unittest.main()




import unittest
import py3kcompat as py3k
from PySide.QtCore import QIODevice, QTextStream


class MyIODevice (QIODevice):
    def readData(self, amount):
        return py3k.b("\0a" * int(amount/2))

    def readLineData(self, maxSize):
        return py3k.b("\0b" * 4)

    def atEnd(self):
        return False

class TestBug944 (unittest.TestCase):

    def testIt(self):
        device = MyIODevice()
        device.open(QIODevice.ReadOnly)
        s = QTextStream(device)
        self.assertEqual(s.read(4), "\0a\0a")
        self.assertEqual(device.readLine(), "\0b\0b\0b\0b")

if __name__ == "__main__":
    unittest.main()




'''Test cases for QUdpSocket'''

import unittest

from PySide.QtCore import QUrl, QObject, SIGNAL, QCoreApplication, QTimer
from PySide.QtNetwork import QUdpSocket, QHostAddress

class HttpSignalsCase(unittest.TestCase):
    '''Test case for bug #124 - readDatagram signature

    QUdpSocket.readDatagram must return a tuple with the datagram, host and
    port, while receiving only the max payload size.'''

    def setUp(self):
        #Acquire resources
        self.called = False
        self.app = QCoreApplication([])

        self.socket = QUdpSocket()

        self.server = QUdpSocket()
        self.server.bind(QHostAddress(QHostAddress.LocalHost), 45454)

    def tearDown(self):
        #Release resources
        del self.socket
        del self.server
        del self.app

    def sendPackage(self):
        addr = QHostAddress(QHostAddress.LocalHost)
        self.socket.writeDatagram('datagram', addr, 45454)

    def callback(self):
        while self.server.hasPendingDatagrams():
            datagram, host, port = self.server.readDatagram(self.server.pendingDatagramSize())
            self.called = True
            self.app.quit()

    def testDefaultArgs(self):
        #QUdpSocket.readDatagram pythonic return
        # @bug 124
        QObject.connect(self.server, SIGNAL('readyRead()'), self.callback)
        self.sendPackage()
        self.app.exec_()

        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()



import unittest

import os
from helper import UsesQApplication
from PySide.QtGui import *
from PySide.QtCore import *

class QPixmapTest(UsesQApplication):
    def testQVariantConstructor(self):
        obj = QObject()
        pixmap = QPixmap()
        obj.setProperty('foo', pixmap)
        self.assertEqual(type(obj.property('foo')), QPixmap)

    def testQSizeConstructor(self):
        pixmap = QPixmap(QSize(10,20))
        self.assert_(pixmap.size().height(), 20)

    def testQStringConstructor(self):
        pixmap = QPixmap("Testing!")

    def testQPixmapLoadFromDataWithQFile(self):
        f = QFile(os.path.join(os.path.dirname(__file__), 'sample.png'))
        self.assert_(f.open(QIODevice.ReadOnly))
        data = f.read(f.size())
        f.close()
        pixmap = QPixmap()
        self.assert_(pixmap.loadFromData(data))

    def testQPixmapLoadFromDataWithPython(self):
        data = open(os.path.join(os.path.dirname(__file__),'sample.png'),'rb').read()
        pixmap = QPixmap()
        self.assert_(pixmap.loadFromData(data))


class QPixmapToImage(UsesQApplication):

    def testFilledImage(self):
        '''QPixmap.fill + toImage + image.pixel'''
        pixmap = QPixmap(100, 200)
        pixmap.fill(Qt.red) # Default Qt.white

        self.assertEqual(pixmap.height(), 200)
        self.assertEqual(pixmap.width(), 100)

        image = pixmap.toImage()

        self.assertEqual(image.height(), 200)
        self.assertEqual(image.width(), 100)

        pixel = image.pixel(10,10)
        self.assertEqual(pixel, QColor(Qt.red).rgba())


if __name__ == '__main__':
    unittest.main()




import unittest
import sys
from PySide.QtCore import QTimer
from PySide.QtGui import QWidget, QApplication

class TestW1(QWidget):
    def __init__(self, parent = None):
        super(TestW1, self).__init__(parent)
        TestW2(parent, self)

class TestW2(QWidget):
    def __init__(self, ancestor, parent = None):
        super(TestW2, self).__init__(parent)
        self.ancestor_ref = ancestor

class Test(QWidget):
    def __init__(self):
        super(Test, self).__init__()
        TestW1(self)

class TestQApplicationDestrcutor(unittest.TestCase):
    def testDestructor(self):
        w = Test()
        w.show()
        QTimer.singleShot(0, w.close)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    unittest.main()
    sys.exit(app.exec_())




import unittest
from helper import UsesQApplication

from PySide.QtCore import Qt, QTimer
from PySide.QtGui import QPen, QPainter, QWidget

class Painting(QWidget):
    def __init__(self):
        QWidget.__init__(self)
        self.penFromEnum = None
        self.penFromInteger = None

    def paintEvent(self, event):
        painter = QPainter(self)
        painter.setPen(Qt.NoPen)
        self.penFromEnum = painter.pen()
        painter.setPen(int(Qt.NoPen))
        self.penFromInteger = painter.pen()


class QPenTest(UsesQApplication):

    def testCtorWithCreatedEnums(self):
        '''A simple case of QPen creation using created enums.'''
        width = 0
        style = Qt.PenStyle(0)
        cap = Qt.PenCapStyle(0)
        join = Qt.PenJoinStyle(0)
        pen = QPen(Qt.blue, width, style, cap, join)

    def testSetPenWithPenStyleEnum(self):
        '''Calls QPainter.setPen with both enum and integer. Bug #511.'''
        w = Painting()
        w.show()
        QTimer.singleShot(1000, self.app.quit)
        self.app.exec_()
        self.assertEqual(w.penFromEnum.style(), Qt.NoPen)
        self.assertEqual(w.penFromInteger.style(), Qt.SolidLine)


if __name__ == '__main__':
    unittest.main()




import unittest
import random
from functools import partial

from PySide.QtCore import QObject, SIGNAL

try:
    from PySide.QtGui import QPushButton, QSpinBox
    hasQtGui = True
except ImportError:
    hasQtGui = False

from helper import BasicPySlotCase, UsesQApplication

class MultipleSignalConnections(unittest.TestCase):
    '''Base class for multiple signal connection testing'''

    def run_many(self, sender, signal, emitter, receivers, args=None):
        """Utility method to connect a list of receivers to a signal.
        sender - QObject that will emit the signal
        signal - string with the signal signature
        emitter - the callable that will trigger the signal
        receivers - list of BasicPySlotCase instances
        args - tuple with the arguments to be sent.
        """

        if args is None:
            args = tuple()

        for rec in receivers:
            rec.setUp()
            QObject.connect(sender, SIGNAL(signal), rec.cb)
            rec.args = tuple(args)

        emitter(*args)

        for rec in receivers:
            self.assert_(rec.called)


if hasQtGui:
    class QtGuiMultipleSlots(UsesQApplication, MultipleSignalConnections):
        '''Multiple connections to QtGui signals'''

        def testButtonClick(self):
            """Multiple connections to QPushButton.clicked()"""
            sender = QPushButton('button')
            receivers = [BasicPySlotCase() for x in range(30)]
            self.run_many(sender, 'clicked()', sender.click, receivers)

        def testSpinBoxValueChanged(self):
            """Multiple connections to QSpinBox.valueChanged(int)"""
            sender = QSpinBox()
            #FIXME if number of receivers if higher than 50, segfaults
            receivers = [BasicPySlotCase() for x in range(10)]
            self.run_many(sender, 'valueChanged(int)', sender.setValue,
                          receivers, (1,))

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide import QtGui, QtCore

class Properties(unittest.TestCase):

    def testStaticProperty(self):
        self.assertEqual(QtGui.QGraphicsItem.UserType, 65536)

    def testInstanceProperty(self):
        p = QtGui.QStyleOptionViewItemV3()
        self.assert_(isinstance(p.locale, QtCore.QLocale))


if __name__ == '__main__':
    unittest.main()



from PySide.QtGui import QMenu, QWidget, QMenuBar, QToolBar
import weakref

import unittest
from helper import UsesQApplication


class TestQActionLifeCycle(UsesQApplication):
    def actionDestroyed(self, act):
        self._actionDestroyed = True

    def testMenu(self):
        self._actionDestroyed = False
        w = QWidget()
        menu = QMenu(w)
        act = menu.addAction("MENU")
        _ref = weakref.ref(act, self.actionDestroyed)
        act = None
        self.assertFalse(self._actionDestroyed)
        menu.clear()
        self.assertTrue(self._actionDestroyed)

    def testMenuBar(self):
        self._actionDestroyed = False
        w = QWidget()
        menuBar = QMenuBar(w)
        act = menuBar.addAction("MENU")
        _ref = weakref.ref(act, self.actionDestroyed)
        act = None
        self.assertFalse(self._actionDestroyed)
        menuBar.clear()
        self.assertTrue(self._actionDestroyed)

    def testToolBar(self):
        self._actionDestroyed = False
        w = QWidget()
        toolBar = QToolBar(w)
        act = toolBar.addAction("MENU")
        _ref = weakref.ref(act, self.actionDestroyed)
        act = None
        self.assertFalse(self._actionDestroyed)
        toolBar.clear()
        self.assertTrue(self._actionDestroyed)

if __name__ == "__main__":
    unittest.main()



import unittest

from PySide.QtCore import QObject

class MyObject(QObject):
    pass

class MainTest(unittest.TestCase):
    def testInherits(self):
        o = MyObject()
        mo = o.metaObject()
        self.assertEqual(mo.className(), 'MyObject')
        self.assertTrue(o.inherits('MyObject'))

if __name__ == '__main__':
    unittest.main()




''' Test case for QObject.signalsBlocked() and blockSignal()'''

import unittest
import os
from tempfile import mkstemp

from PySide.QtCore import QObject, SIGNAL, QFile

class TestSignalsBlockedBasic(unittest.TestCase):
    '''Basic test case for signalsBlocked'''

    def testBasic(self):
        '''QObject.signalsBlocked() and blockSignals()
        The signals aren't blocked by default.
        blockSignals returns the previous value'''
        obj = QObject()
        self.assert_(not obj.signalsBlocked())
        self.assert_(not obj.blockSignals(True))
        self.assert_(obj.signalsBlocked())
        self.assert_(obj.blockSignals(False))

class TestSignalsBlocked(unittest.TestCase):
    '''Test case to check if the signals are really blocked'''

    def setUp(self):
        #Set up the basic resources needed
        self.obj = QObject()
        self.args = tuple()
        self.called = False

    def tearDown(self):
        #Delete used resources
        del self.obj
        del self.args

    def callback(self, *args):
        #Default callback
        if  args == self.args:
            self.called = True
        else:
            raise TypeError("Invalid arguments")

    def testShortCircuitSignals(self):
        #Blocking of Python short-circuit signals
        QObject.connect(self.obj, SIGNAL('mysignal'), self.callback)

        self.obj.emit(SIGNAL('mysignal'))
        self.assert_(self.called)

        self.called = False
        self.obj.blockSignals(True)
        self.obj.emit(SIGNAL('mysignal'))
        self.assert_(not self.called)

    def testPythonSignals(self):
        #Blocking of Python typed signals
        QObject.connect(self.obj, SIGNAL('mysignal(int,int)'), self.callback)
        self.args = (1, 3)

        self.obj.emit(SIGNAL('mysignal(int,int)'), *self.args)
        self.assert_(self.called)

        self.called = False
        self.obj.blockSignals(True)
        self.obj.emit(SIGNAL('mysignal(int,int)'), *self.args)
        self.assert_(not self.called)

class TestQFileSignalBlocking(unittest.TestCase):
    '''Test case for blocking the signal QIODevice.aboutToClose()'''

    def setUp(self):
        #Set up the needed resources - A temp file and a QFile
        self.called = False
        handle, self.filename = mkstemp()
        os.close(handle)

        self.qfile = QFile(self.filename)

    def tearDown(self):
        #Release acquired resources
        os.remove(self.filename)
        del self.qfile

    def callback(self):
        #Default callback
        self.called = True

    def testAboutToCloseBlocking(self):
        #QIODevice.aboutToClose() blocking

        QObject.connect(self.qfile, SIGNAL('aboutToClose()'), self.callback)

        self.assert_(self.qfile.open(QFile.ReadOnly))
        self.qfile.close()
        self.assert_(self.called)

        self.called = False
        self.qfile.blockSignals(True)

        self.assert_(self.qfile.open(QFile.ReadOnly))
        self.qfile.close()
        self.assert_(not self.called)


if __name__ == '__main__':
    unittest.main()



import unittest
import datetime

from PySide.QtCore import QDateTime, QDate, QTime

class TestQDate (unittest.TestCase):
    def testDateConversion(self):
        dateTime = QDateTime(QDate(2011, 5, 17), QTime(11, 1, 14, 15))
        dateTimePy = QDateTime(datetime.date(2011, 5, 17), datetime.time(11, 1, 14, 15000))
        self.assertEqual(dateTime, dateTimePy)

    def testDateTimeConversion(self):
        dateTime = QDateTime(QDate(2011, 5, 17), QTime(11, 1, 14, 15))
        dateTimePy = QDateTime(datetime.datetime(2011, 5, 17, 11, 1, 14, 15000))
        self.assertEqual(dateTime, dateTimePy)

    def testDateTimeNow(self):
        py = datetime.datetime.now()
        qt = QDateTime(py)
        self.assertEqual(qt, py)

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtGui import *

class TestBug549(unittest.TestCase):
    def testBug(self):
        app = QApplication([])
        w = QGraphicsWidget()
        w.setContentsMargins(1, 2, 3, 4)
        self.assertEquals(w.getContentsMargins(), (1, 2, 3, 4))
        w.setWindowFrameMargins(5, 6, 7, 8)
        self.assertEquals(w.getWindowFrameMargins(), (5, 6, 7, 8))

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide import QtGui

class BuggyWidget(QtGui.QWidget):
    def setup(self):
        self.verticalLayout = QtGui.QVBoxLayout(self)
        self.gridLayout = QtGui.QGridLayout()
        self.lbl = QtGui.QLabel(self)
        self.gridLayout.addWidget(self.lbl, 0, 1, 1, 1)

        # this cause a segfault during the ownership transfer
        self.verticalLayout.addLayout(self.gridLayout)

class LayoutTransferOwnerShip(unittest.TestCase):
    def testBug(self):
        app = QtGui.QApplication([])
        w = BuggyWidget()
        w.setup()
        w.show()
        self.assert_(True)

if __name__ == '__main__':
    unittest.main()




from PySide.QtGui import *
from PySide.QtCore import *

class QtKeyPressListener(QObject):
    def __init__(self, obj):
        QObject.__init__(self)
        obj.installEventFilter(self)

    def eventFilter(self, obj, event):
        # This used to crash here due to a misbehaviour of type discovery!
        return QObject.eventFilter(self, obj, event)

app = QApplication([])
key_listener = QtKeyPressListener(app)
w = QLabel('Hello')
w.show()
QTimer.singleShot(0, w.close)
app.exec_()



#!/usr/bin/python

import unittest

from PySide import QtCore

def setValue(o):
    values = ['Name']
    o.setProperty('test1', values)

class QQtVersionTest(unittest.TestCase):
    '''Tests for QVariant conversion of QStringList'''

    def testGet(self):
        o = QtCore.QObject()
        setValue(o)
        self.assertEqual(o.property('test1'), ['Name'])



if __name__ == '__main__':
    unittest.main()





from PySide.QtCore import *

class Dispatcher(QObject):
    _me = None

    def __init__(self):
        super(Dispatcher, self).__init__()
        self._me = self
        QTimer.singleShot(0, self._finish)

    def _finish(self):
        del self._me # It can't crash here!
        QTimer.singleShot(10, QCoreApplication.instance().quit)

if __name__ == '__main__':
    app = QCoreApplication([])
    Dispatcher()
    app.exec_()



import unittest

from PySide.QtCore import QObject

class MyBaseObject(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.setObjectName("PySide")

    def __del__(self):
        if self.objectName() != "PySide":
            raise NameError('Fail')

class CheckForEventsTypes(unittest.TestCase):
    def testDelObject(self):
        p = MyBaseObject()
        o = MyBaseObject(p)
        del o
        del p

if __name__ == '__main__':
    unittest.main()




'''Tests for inject codes and modifications on QFontMetrics
   and QFontMetricsF'''

import unittest
from PySide.QtGui import QFont, QFontMetrics, QFontMetricsF
from PySide.QtCore import QRect, QRectF, Qt, QSize, QSizeF
from helper import UsesQApplication


class QFontMetricsTest(UsesQApplication):
    '''Base class for QFontMetrics tests'''

    def setUp(self):
        super(QFontMetricsTest, self).setUp()
        self.font = QFont()
        self.metrics = QFontMetrics(self.font)

    def tearDown(self):
        del self.metrics
        del self.font
        super(QFontMetricsTest, self).tearDown()


class BoundingRectTest(QFontMetricsTest):
    '''Tests for QFontMetrics.boundingRect inject code'''

    def testIntDefault(self):
        '''QFontMetrics.boundingRect(int, int, int, int, ...) - default args'''
        rect = self.metrics.boundingRect(0, 0, 0, 0,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT')
        self.assertTrue(isinstance(rect, QRect))

    def testIntWithArg(self):
        '''QFontMetrics.boundingRect(int, int, int, int, ...) - single arg'''
        rect = self.metrics.boundingRect(0, 0, 0, 0,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 2)
        self.assertTrue(isinstance(rect, QRect))

    def testIntWithFull(self):
        '''QFontMetrics.boundingRect(int, int, int, int, ...) - all argss'''
        rect = self.metrics.boundingRect(0, 0, 0, 0,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20, [1, 2, 3, 4, 5])
        self.assertTrue(isinstance(rect, QRect))

    def testIntTypeError(self):
        '''QFontMetrics.boundingRect(int, int, int, int, ...) - type error'''
        self.assertRaises(TypeError, self.metrics.boundingRect, 0, 0, 0, 0,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20, ['aaaa', 'ase'])

    def testQRectDefault(self):
        '''QFontMetrics.boundingRect(QRect, ...) - default args'''
        arg = QRect(0, 0, 100, 200)
        rect = self.metrics.boundingRect(arg, Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT')
        self.assertTrue(isinstance(rect, QRect))

    def testQRectWithArg(self):
        '''QFontMetrics.boundingRect(QRect, ...) - only tabstops'''
        arg = QRect(0, 0, 100, 200)
        rect = self.metrics.boundingRect(arg, Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 2)
        self.assertTrue(isinstance(rect, QRect))

    def testQRectWithFull(self):
        '''QFontMetrics.boundingRect(QRect, ...) - all arguments'''
        arg = QRect(0, 0, 100, 200)
        rect = self.metrics.boundingRect(arg, Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20,
                                         [1, 2, 3, 4, 5])
        self.assertTrue(isinstance(rect, QRect))

    def testQRectTypeError(self):
        '''QFontMetrics.boundingRect(QRect, ...) - type error'''
        arg = QRect(0, 0, 100, 200)
        self.assertRaises(TypeError, self.metrics.boundingRect, arg,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20, ['aaaa', 'ase'])


class SizeTest(QFontMetricsTest):
    '''Tests for QFontMetrics.size inject code'''

    def testDefault(self):
        '''QFontMetrics.size - default arguments'''
        size = self.metrics.size(Qt.TextExpandTabs | Qt.TextSingleLine,
                                 'PySide by INdT')
        self.assertTrue(isinstance(size, QSize))

    def testWithTabStops(self):
        '''QFontMetrics.size - only tabstops'''
        size = self.metrics.size(Qt.TextExpandTabs | Qt.TextSingleLine,
                                 'PySide by INdT', 2)
        self.assertTrue(isinstance(size, QSize))

    def testFull(self):
        '''QFontMetrics.size - all arguments'''
        size = self.metrics.size(Qt.TextExpandTabs | Qt.TextSingleLine,
                                 'PySide by INdT', 2, [1, 2, 3, 4])
        self.assertTrue(isinstance(size, QSize))

    def testTypeError(self):
        '''QFontMetrics.size - type error'''
        self.assertRaises(TypeError, self.metrics.size,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20, ['aaaa', 'ase'])


class QFontMetricsFTest(UsesQApplication):
    '''Base class for QFontMetrics tests'''

    def setUp(self):
        super(QFontMetricsFTest, self).setUp()
        self.font = QFont()
        self.metrics = QFontMetricsF(self.font)

    def tearDown(self):
        del self.metrics
        del self.font
        super(QFontMetricsFTest, self).tearDown()


class FBoundingRectTest(QFontMetricsFTest):
    '''Tests for QFontMetricsF.boundingRect inject code'''

    def testQRectDefault(self):
        '''QFontMetricsF.boundingRect(QRectF, ...) - default args'''
        arg = QRectF(0, 0, 100, 200)
        rect = self.metrics.boundingRect(arg, Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT')
        self.assertTrue(isinstance(rect, QRectF))

    def testQRectWithArg(self):
        '''QFontMetricsF.boundingRect(QRectF, ...) - only tabstops'''
        arg = QRectF(0, 0, 100, 200)
        rect = self.metrics.boundingRect(arg, Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 2)
        self.assertTrue(isinstance(rect, QRectF))

    def testQRectWithFull(self):
        '''QFontMetricsF.boundingRect(QRectF, ...) - all arguments'''
        arg = QRectF(0, 0, 100, 200)
        rect = self.metrics.boundingRect(arg, Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20,
                                         [1, 2, 3, 4, 5])
        self.assertTrue(isinstance(rect, QRectF))

    def testQRectTypeError(self):
        '''QFontMetricsF.boundingRect(QRectF, ...) - type error'''
        arg = QRectF(0, 0, 100, 200)
        self.assertRaises(TypeError, self.metrics.boundingRect, arg,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20, ['aaaa', 'ase'])


class FSizeTest(QFontMetricsFTest):
    '''Tests for QFontMetricsF.size inject code'''

    def testDefault(self):
        '''QFontMetricsF.size - default arguments'''
        size = self.metrics.size(Qt.TextExpandTabs | Qt.TextSingleLine,
                                 'PySide by INdT')
        self.assertTrue(isinstance(size, QSizeF))

    def testWithTabStops(self):
        '''QFontMetricsF.size - only tabstops'''
        size = self.metrics.size(Qt.TextExpandTabs | Qt.TextSingleLine,
                                 'PySide by INdT', 2)
        self.assertTrue(isinstance(size, QSizeF))

    def testFull(self):
        '''QFontMetricsF.size - all arguments'''
        size = self.metrics.size(Qt.TextExpandTabs | Qt.TextSingleLine,
                                 'PySide by INdT', 2, [1, 2, 3, 4])
        self.assertTrue(isinstance(size, QSizeF))

    def testTypeError(self):
        '''QFontMetricsF.size - type error'''
        self.assertRaises(TypeError, self.metrics.size,
                                         Qt.TextExpandTabs | Qt.AlignLeft,
                                         'PySide by INdT', 20, ['aaaa', 'ase'])


class QCharTest(QFontMetricsFTest):

    def testBoundingRect(self):
        retCh = self.metrics.boundingRectChar('a')
        self.assertEqual(type(retCh), QRectF)

    def testWith(self):
        retCh = self.metrics.widthChar('a')
        self.assertTrue(retCh > 0)

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtHelp import QHelpEngine

from helper import UsesQApplication

class QHelpEngineCreation(UsesQApplication):

    def testConstructor(self):
        helpEngine = QHelpEngine('mycollection.qch')

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtGui import QRadialGradient
from PySide.QtCore import QPointF

class QRadialGradientConstructor(unittest.TestCase):
    def _compare(self, qptf, tpl):
        self.assertEqual((qptf.x(), qptf.y()), tpl)

    def _assertValues(self, grad):
        self._compare(grad.center(), (1.0, 2.0))
        self._compare(grad.focalPoint(), (3.0, 4.0))
        self.assertEqual(grad.radius(), 5.0)

    def testAllInt(self):
        grad = QRadialGradient(1, 2, 5, 3, 4)
        self._assertValues(grad)

    def testQPointF(self):
        grad = QRadialGradient(QPointF(1, 2), 5, QPointF(3, 4))
        self._assertValues(grad)

    def testSetQPointF(self):
        grad = QRadialGradient()
        grad.setCenter(QPointF(1, 2))
        self._compare(grad.center(), (1.0, 2.0))

if __name__ == '__main__':
    unittest.main()



import unittest
import sys
import weakref

from helper import UsesQApplication

from PySide.QtGui import QTextBlockUserData, QTextEdit, QTextCursor

class TestUserData(QTextBlockUserData):
    def __init__(self, data):
        super(TestUserData, self).__init__()
        self.data = data

class TestUserDataRefCount(UsesQApplication):
    def testRefcount(self):
        textedit = QTextEdit()
        textedit.setReadOnly(True)
        doc = textedit.document()
        cursor = QTextCursor(doc)
        cursor.insertText("PySide Rocks")
        ud = TestUserData({"Life": 42})
        self.assertEqual(sys.getrefcount(ud), 2)
        cursor.block().setUserData(ud)
        self.assertEqual(sys.getrefcount(ud), 3)
        ud2 = cursor.block().userData()
        self.assertEqual(sys.getrefcount(ud), 4)
        self.udata = weakref.ref(ud, None)
        del ud, ud2
        self.assertEqual(sys.getrefcount(self.udata()), 2)

if __name__ == '__main__':
    unittest.main()



import unittest
from helper import UsesQApplication
from PySide.QtGui import QLineEdit, QValidator, QIntValidator

'''Bug #871 - http://bugs.pyside.org/show_bug.cgi?id=871'''


class BlankIntValidator(QIntValidator):
    def validate(self,input,pos):
        if input == '':
            return QValidator.Acceptable, input, pos
        else:
            return QIntValidator.validate(self,input,pos)


class Bug871Test(UsesQApplication):
    def testWithoutValidator(self):
        edit = QLineEdit()
        self.assertEqual(edit.text(), '')
        edit.insert('1')
        self.assertEqual(edit.text(), '1')
        edit.insert('a')
        self.assertEqual(edit.text(), '1a')
        edit.insert('2')
        self.assertEqual(edit.text(), '1a2')

    def testWithIntValidator(self):
        edit = QLineEdit()
        edit.setValidator(BlankIntValidator(edit))
        self.assertEqual(edit.text(), '')
        edit.insert('1')
        self.assertEqual(edit.text(), '1')
        edit.insert('a')
        self.assertEqual(edit.text(), '1')
        edit.insert('2')
        self.assertEqual(edit.text(), '12')


if __name__ == "__main__":
   unittest.main()





import unittest

from PySide.QtCore import QObject, SIGNAL, SLOT

class Dummy(QObject):
    """Dummy class used in this test."""
    def __init__(self, parent=None):
        QObject.__init__(self, parent)

class ShortCircuitSignals(unittest.TestCase):
    def setUp(self):
        self.called = False

    def tearDown(self):
        try:
            del self.args
        except:
            pass

    def callback(self, *args):
        if tuple(self.args) == args:
            self.called = True

    def testNoArgs(self):
        """Short circuit signal without arguments"""
        obj1 = Dummy()

        QObject.connect(obj1, SIGNAL('foo'), self.callback)
        self.args = tuple()
        obj1.emit(SIGNAL('foo'), *self.args)

        self.assert_(self.called)

    def testWithArgs(self):
        """Short circuit signal with integer arguments"""
        obj1 = Dummy()

        QObject.connect(obj1, SIGNAL('foo'), self.callback)
        self.args = (42,)
        obj1.emit(SIGNAL('foo'), *self.args)

        self.assert_(self.called)

    def testMultipleArgs(self):
        """Short circuit signal with multiple arguments"""
        obj1 = Dummy()

        QObject.connect(obj1, SIGNAL('foo'), self.callback)
        self.args = (42,33,'char')
        obj1.emit(SIGNAL('foo'), *self.args)

        self.assert_(self.called)

    def testComplexArgs(self):
        """Short circuit signal with complex arguments"""
        obj1 = Dummy()

        QObject.connect(obj1, SIGNAL('foo'), self.callback)
        self.args = (42, obj1)
        obj1.emit(SIGNAL('foo'), *self.args)

        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

''' Test case for QAbstractListModel.createIndex and QModelIndex.internalPointer'''

import sys
import unittest
from PySide.QtCore import *

class MyModel (QAbstractListModel):
    pass

class TestQModelIndexInternalPointer(unittest.TestCase):
    ''' Test case for QAbstractListModel.createIndex and QModelIndex.internalPointer'''

    def setUp(self):
        #Acquire resources
        self.model = MyModel()

    def tearDown(self):
        #Release resources
        del self.model

    def testInternalPointer(self):
        #Test QAbstractListModel.createIndex and
        #QModelIndex.internalPointer with regular
        #Python objects
        idx = self.model.createIndex(0, 0, "Hello")
        self.assertEqual("Hello", idx.internalPointer())
        a = [1, 2, 3]
        idx = self.model.createIndex(0, 0, a)
        self.assertEqual(a, idx.internalPointer())

    def testReferenceCounting(self):
        #Test reference counting when retrieving data with
        #QModelIndex.internalPointer
        a = [1, 2, 3]
        a_refcnt = sys.getrefcount(a)
        idx = self.model.createIndex(0, 0, a)
        ptr = idx.internalPointer()
        self.assertEqual(sys.getrefcount(a), a_refcnt + 1)

    def testIndexForDefaultDataArg(self):
        #Test QAbstractListModel.createIndex with a default
        #value for data argument
        idx = self.model.createIndex(0, 0)
        self.assertEqual(None, idx.internalPointer())

if __name__ == '__main__':
    unittest.main()





'''Test cases for bug: http://bugs.openbossa.org/show_bug.cgi?id=448'''

import unittest
import sys

from PySide.QtGui import QApplication
from PySide.QtWebKit import QWebView

class Bug448(unittest.TestCase):
    def onError(self, erros):
        pass

    def testReturnOwnership(self):
        app = QApplication(sys.argv)
        webview = QWebView()
        webview.page().networkAccessManager().sslErrors.connect(self.onError)

if __name__ == '__main__':
    unittest.main()
